__all__=['', '_GetInterfaceCount', '_GetInterfaceCount', 'CoCreateFreeThreadedMarshaler', 'CoCreateInstanceEx', 'CoCreateInstance', 'CoFreeUnusedLibraries', 'CoInitialize', 'CoInitializeEx', 'CoInitializeSecurity', 'CoGetInterfaceAndReleaseStream', 'CoMarshalInterThreadInterfaceInStream', 'CoMarshalInterface', 'CoUnmarshalInterface', 'CoReleaseMarshalData', 'CoGetObject', 'CoUninitialize', 'CoRegisterClassObject', 'CoResumeClassObjects', 'CoRevokeClassObject', 'CoTreatAsClass', 'CoWaitForMultipleHandles', 'Connect', 'CreateGuid', 'CreateBindCtx', 'CreateFileMoniker', 'CreateItemMoniker', 'CreatePointerMoniker', 'CreateTypeLib', 'CreateTypeLib2', 'CreateStreamOnHGlobal', 'CreateILockBytesOnHGlobal', 'EnableQuitMessage', 'FUNCDESC', 'GetActiveObject', 'GetClassFile', 'GetFacilityString', 'GetRecordFromGuids', 'GetRecordFromTypeInfo', 'GetRunningObjectTable', 'GetScodeString', 'GetScodeRangeString', 'GetSeverityString', 'IsGatewayRegistered', 'LoadRegTypeLib', 'LoadTypeLib', 'MakePyFactory', 'MkParseDisplayName', 'New', 'ObjectFromAddress', 'ObjectFromLresult', 'OleInitialize', 'OleGetClipboard', 'OleFlushClipboard', 'OleIsCurrentClipboard', 'OleSetClipboard', 'OleLoadFromStream', 'OleSaveToStream', 'OleLoad', 'ProgIDFromCLSID', 'PumpWaitingMessages', 'PumpMessages', 'QueryPathOfRegTypeLib', 'ReadClassStg', 'ReadClassStm', 'RegisterTypeLib', 'UnRegisterTypeLib', 'RegisterActiveObject', 'RevokeActiveObject', 'RegisterDragDrop', 'RevokeDragDrop', 'DoDragDrop', 'StgCreateDocfile', 'StgCreateDocfileOnILockBytes', 'StgOpenStorageOnILockBytes', 'StgIsStorageFile', 'STGMEDIUM', 'StgOpenStorage', 'StgOpenStorageEx', 'StgCreateStorageEx', 'TYPEATTR', 'VARDESC', 'WrapObject', 'WriteClassStg', 'WriteClassStm', 'UnwrapObject', 'FmtIdToPropStgName', 'PropStgNameToFmtId', 'CoGetCallContext', 'CoGetObjectContext', 'CoGetCancelObject', 'CoSetCancelObject', 'CoEnableCallCancellation', 'CoDisableCallCancellation']
import typing
import win32typing
"""A module, encapsulating the OLE automation API"""


def _GetInterfaceCount() -> 'typing.Any':
    """
    Retrieves the number of interface objects currently in existance

Args:



Returns:

      typing.Any
        
    """
    pass
        

def _GetInterfaceCount() -> 'typing.Any':
    """
    Retrieves the number of interface objects currently in existance

Args:



Returns:

      typing.Any
        
    """
    pass
        

def CoCreateFreeThreadedMarshaler(unk:'win32typing.PyIUnknown') -> 'win32typing.PyIUnknown':
    """
    Creates an aggregatable object capable of 

context-dependent marshaling.

Args:

      unk(win32typing.PyIUnknown):The unknown object to marshal.

Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def CoCreateInstanceEx(clsid:'win32typing.PyIID',unkOuter:'win32typing.PyIUnknown',context:'typing.Any',serverInfo:'typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]',iids:'typing.List[win32typing.PyIID]') -> 'win32typing.PyIUnknown':
    """
    Create a new instance of an OLE automation server possibly on a 

remote machine.

Args:

      clsid(win32typing.PyIID):Class identifier (CLSID) of the object
      unkOuter(win32typing.PyIUnknown):The outer unknown, or None
      context(typing.Any):The create context for the object, combination of pythoncom.CLSCTX_* flags
      serverInfo(typing.Tuple[typing.Any, typing.Any, typing.Any, typing.Any]):May be None, or describes the remote server to execute on.
      iids(typing.List[win32typing.PyIID]):A list of IIDs required from the object

Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def CoCreateInstance(clsid:'win32typing.PyIID',unkOuter:'win32typing.PyIUnknown',context:'typing.Any',iid:'win32typing.PyIID') -> 'win32typing.PyIUnknown':
    """
    Create a new instance of an OLE automation server.

Args:

      clsid(win32typing.PyIID):Class identifier (CLSID) of the object
      unkOuter(win32typing.PyIUnknown):The outer unknown, or None
      context(typing.Any):The create context for the object, combination of pythoncom.CLSCTX_* flags
      iid(win32typing.PyIID):The IID required from the object

Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def CoFreeUnusedLibraries() -> 'None':
    """
    Unloads any DLLs that are no longer in use and that, when loaded, were 

specified to be freed automatically.

Args:



Returns:

      None
        
    """
    pass
        

def CoInitialize() -> 'None':
    """
    Initialize the COM libraries for the calling thread.

Args:



Returns:

      None:pythoncom.CoInitialize
CoInitialize()Initialize the COM libraries for the calling thread.
Comments

Apart from the error handling semantics, this is equivalent 

to pythoncom::CoInitializeEx(pythoncom.COINIT_APARTMENTTHREADED). 

See pythoncom::CoInitializeEx for a description.
Return ValueThis function will ignore the RPC_E_CHANGED_MODE error, as 

that error indicates someone else beat you to the initialization, and 

did so with a different threading model.  This error is ignored as it 

still means COM is ready for use on this thread, and as this function 

does not explicitly specify a threading model the caller probably 

doesn't care what model it is. 

All other COM errors will raise pythoncom.error as usual.  Use 

pythoncom::CoInitializeEx if you also want to handle the RPC_E_CHANGED_MODE 

error.

        
    """
    pass
        

def CoInitializeEx(flags:'typing.Any') -> 'None':
    """
    Initialize the COM libraries for the calling thread.

Args:

      flags(typing.Any):Flags for the initialization.CommentsThere is no need to call this for the main Python thread, as it is called automatically by pythoncom (using sys.coinit_flags as the param, or COINIT_APARTMENTTHREADED if sys.coinit_flags does not exist). You must call this manually if you create a thread which wishes to use COM.Return ValueThis function will raise pythoncom.error for all error return values, including RPC_E_CHANGED_MODE error.  This is in contrast to pythoncom::CoInitialize which will hide that specific error.  If your code is happy to work in a threading model other than the one you specified, you must explicitly handle (and presumably ignore) this exception.

Returns:

      None:Flags for the initialization.Comments

There is no need to call this for the main Python thread, as it is called 

automatically by pythoncom (using sys.coinit_flags as the param, or COINIT_APARTMENTTHREADED 

if sys.coinit_flags does not exist). 

You must call this manually if you create a thread which wishes to use COM.
Return ValueThis function will raise pythoncom.error for all error 

return values, including RPC_E_CHANGED_MODE error.  This is 

in contrast to pythoncom::CoInitialize which will hide that 

specific error.  If your code is happy to work in a threading model 

other than the one you specified, you must explicitly handle 

(and presumably ignore) this exception.

        
    """
    pass
        

def CoInitializeSecurity(sd:'win32typing.PySECURITY_DESCRIPTOR',authSvc:'typing.Any',reserved1:'typing.Any',authnLevel:'typing.Any',impLevel:'typing.Any',authInfo:'typing.Any',capabilities:'typing.Any',reserved2:'typing.Any') -> 'None':
    """
    Registers security and sets the default security values.

Args:

      sd(win32typing.PySECURITY_DESCRIPTOR):Security descriptor containing access permissions for process' objects, can be None. If Capabilities contains EOAC_APPID, sd should be an AppId (guid), or None to use server executable. If Capabilities contains EOAC_ACCESS_CONTROL, sd parameter should be an IAccessControl interface.
      authSvc(typing.Any):A value of None tells COM to choose which authentication services to use.  An empty list means use no services.
      reserved1(typing.Any):Must be None
      authnLevel(typing.Any):One of pythoncom.RPC_C_AUTHN_LEVEL_* values. The default authentication level for proxies. On the server side, COM will fail calls that arrive at a lower level. All calls to AddRef and Release are made at this level.
      impLevel(typing.Any):One of pythoncom.RPC_C_IMP_LEVEL_* values.  The default impersonation level for proxies. This value is not checked on the server side. AddRef and Release calls are made with this impersonation level so even security aware apps should set this carefully. Setting IUnknown security only affects calls to QueryInterface, not AddRef or Release.
      authInfo(typing.Any):Must be None
      capabilities(typing.Any):Authentication capabilities, combination of pythoncom.EOAC_* flags.
      reserved2(typing.Any):Must be None

Returns:

      None
        
    """
    pass
        

def CoGetInterfaceAndReleaseStream(stream:'win32typing.PyIStream',iid:'win32typing.PyIID') -> 'win32typing.PyIUnknown':
    """
    Unmarshals a buffer containing an interface pointer 

and releases the stream when an interface pointer has been marshaled from another thread to the calling thread.

Args:

      stream(win32typing.PyIStream):The stream to unmarshal the object from.
      iid(win32typing.PyIID):The IID if the interface to unmarshal.

Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def CoMarshalInterThreadInterfaceInStream(iid:'win32typing.PyIID',unk:'win32typing.PyIUnknown') -> 'win32typing.PyIStream':
    """
    Marshals an interface pointer from one thread 

to another thread in the same process.

Args:

      iid(win32typing.PyIID):The IID of the interface to marshal.
      unk(win32typing.PyIUnknown):The interface to marshal.

Returns:

      win32typing.PyIStream
        
    """
    pass
        

def CoMarshalInterface(Stm:'win32typing.PyIStream',riid:'win32typing.PyIID',Unk:'win32typing.PyIUnknown',DestContext:'typing.Any',flags:'typing.Any') -> 'None':
    """
    Marshals an interface into a stream

Args:

      Stm(win32typing.PyIStream):An IStream interface into which marshalled interface will be written
      riid(win32typing.PyIID):IID of interface to be marshalled
      Unk(win32typing.PyIUnknown):Base IUnknown of the object to be marshalled
      DestContext(typing.Any):MSHCTX_* flag indicating where object will be unmarshalled
      flags(typing.Any):MSHLFLAGS_* flag indicating marshalling options

Returns:

      None
        
    """
    pass
        

def CoUnmarshalInterface(Stm:'win32typing.PyIStream',riid:'win32typing.PyIID') -> 'typing.Any':
    """
    Unmarshals an interface

Args:

      Stm(win32typing.PyIStream):Stream containing marshalled interface
      riid(win32typing.PyIID):IID of interface to be unmarshalled

Returns:

      typing.Any
        
    """
    pass
        

def CoReleaseMarshalData(Stm:'win32typing.PyIStream') -> 'None':
    """
    Frees resources used by a marshalled interface

Args:

      Stm(win32typing.PyIStream):Stream containing marshalled interfaceCommentsThis is usually only needed when the interface could not be successfully unmarshalled

Returns:

      None
        
    """
    pass
        

def CoGetObject(name:'str',iid:'win32typing.PyIID',bindOpts:'typing.Any'=None) -> 'win32typing.PyIUnknown':
    """
    Converts a display name into a moniker that identifies the object 

named, and then binds to the object identified by the moniker.

Args:

      name(str):
      iid(win32typing.PyIID):The IID of the interface to return.
      bindOpts(typing.Any):Must be None

Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def CoUninitialize() -> 'None':
    """
    Uninitialize the COM libraries for the calling thread.

Args:



Returns:

      None
        
    """
    pass
        

def CoRegisterClassObject(iid:'win32typing.PyIID',factory:'win32typing.PyIUnknown',context:'typing.Any',flags:'typing.Any') -> 'typing.Any':
    """
    Registers an EXE class object with OLE so other applications can 

connect to it.

Args:

      iid(win32typing.PyIID):The IID of the object to register
      factory(win32typing.PyIUnknown):The class factory object.  It is the Python programmers responsibility to ensure this object remains alive until the class is unregistered.
      context(typing.Any):The create context for the server.  Must be a combination of the CLSCTX_* flags.
      flags(typing.Any):Create flags.CommentsThe class factory object should be PyIClassFactory object, but as per the COM documentation, only PyIUnknown is checked.Return ValueThe result is a handle which should be revoked using pythoncom::CoRevokeClassObject

Returns:

      typing.Any:Create flags.Comments

The class factory object should be PyIClassFactory object, but as per the COM documentation, only PyIUnknown is checked.
Return ValueThe result is a handle which should be revoked using pythoncom::CoRevokeClassObject

        
    """
    pass
        

def CoResumeClassObjects() -> 'None':
    """
    Called by a server that can register multiple class objects to inform the 

OLE SCM about all registered classes, and permits activation requests for those class objects.

Args:



Returns:

      None
        
    """
    pass
        

def CoRevokeClassObject(reg:'typing.Any') -> 'None':
    """
    None

Args:

      reg(typing.Any):The value returned from pythoncom::CoRegisterClassObject

Returns:

      None
        
    """
    pass
        

def CoTreatAsClass(clsidold:'win32typing.PyIID',clsidnew:'win32typing.PyIID') -> 'None':
    """
    Establishes or removes an emulation, in which objects of one class are treated as 

objects of a different class.

Args:

      clsidold(win32typing.PyIID):CLSID of the object to be emulated.
      clsidnew(win32typing.PyIID):CLSID of the object that should emulate the original object. This replaces any existing emulation for clsidOld. Can be ommitted or CLSID_NULL, in which case any existing emulation for clsidOld is removed.

Returns:

      None
        
    """
    pass
        

def CoWaitForMultipleHandles(Flags:'typing.Any',Timeout:'typing.Any',Handles:'typing.List[int]') -> 'typing.Any':
    """
    Waits for specified handles to be signaled or for a specified 

timeout period to elapse.

Args:

      Flags(typing.Any):Combination of pythoncom.COWAIT_* values
      Timeout(typing.Any):Timeout in milliseconds
      Handles(typing.List[int]):Sequence of handles

Returns:

      typing.Any
        
    """
    pass
        

def Connect(cls:'typing.Any') -> 'win32typing.PyIDispatch':
    """
    Connect to an already running OLE automation server.

Args:

      cls(typing.Any):An identifier for the program.  Usually "program.item"CommentsThis function is equivalent to pythoncom::GetActiveObject(clsid).pythoncom::QueryInterace(pythoncom.IID_IDispatch)

Returns:

      win32typing.PyIDispatch
        
    """
    pass
        

def CreateGuid() -> 'win32typing.PyIID':
    """
    Creates a new, unique GUIID.

Args:



Returns:

      win32typing.PyIID
        
    """
    pass
        

def CreateBindCtx() -> 'win32typing.PyIBindCtx':
    """
    None

Args:



Returns:

      win32typing.PyIBindCtx
        
    """
    pass
        

def CreateFileMoniker(filename:'str') -> 'win32typing.PyIMoniker':
    """
    None

Args:

      filename(str):The name of the file.

Returns:

      win32typing.PyIMoniker
        
    """
    pass
        

def CreateItemMoniker(delim:'str',item:'str') -> 'win32typing.PyIMoniker':
    """
    Creates an item moniker 

that identifies an object within a containing object (typically a compound document).

Args:

      delim(str):String containing the delimiter (typically "!") used to separate this item's display name from the display name of its containing object.
      item(str):String indicating the containing object's name for the object being identified.

Returns:

      win32typing.PyIMoniker
        
    """
    pass
        

def CreatePointerMoniker(IUnknown:'win32typing.PyIUnknown') -> 'win32typing.PyIMoniker':
    """
    None

Args:

      IUnknown(win32typing.PyIUnknown):The interface for the moniker.

Returns:

      win32typing.PyIMoniker
        
    """
    pass
        

def CreateTypeLib() -> 'typing.Any':
    """
    Provides access to a new object instance that supports the 

ICreateTypeLib interface.

Args:



Returns:

      typing.Any
        
    """
    pass
        

def CreateTypeLib2() -> 'typing.Any':
    """
    Provides access to a new object instance that supports the 

ICreateTypeLib2 interface.

Args:



Returns:

      typing.Any
        
    """
    pass
        

def CreateStreamOnHGlobal(hGlobal:'int'=None,DeleteOnRelease:'typing.Any'=True) -> 'win32typing.PyIStream':
    """
    Creates an in-memory stream storage object

Args:

      hGlobal(int):Global memory handle.  If None, a new global memory object is allocated.
      DeleteOnRelease(typing.Any):Indicates if global memory should be freed when IStream object is destroyed.

Returns:

      win32typing.PyIStream
        
    """
    pass
        

def CreateILockBytesOnHGlobal(hGlobal:'int'=None,DeleteOnRelease:'typing.Any'=True) -> 'win32typing.PyILockBytes':
    """
    Creates an ILockBytes interface based on global memory

Args:

      hGlobal(int):Global memory handle.  If None, a new global memory object is allocated.
      DeleteOnRelease(typing.Any):Indicates if global memory should be freed when interface is released.

Returns:

      win32typing.PyILockBytes
        
    """
    pass
        

def EnableQuitMessage(threadId:'typing.Any') -> 'None':
    """
    Indicates the thread PythonCOM should post a WM_QUIT message to.

Args:

      threadId(typing.Any):The thread ID.

Returns:

      None
        
    """
    pass
        

def FUNCDESC() -> 'win32typing.FUNCDESC':
    """
    Creates a new FUNCDESC object

Args:



Returns:

      win32typing.FUNCDESC
        
    """
    pass
        

def GetActiveObject(cls:'typing.Any') -> 'win32typing.PyIUnknown':
    """
    Retrieves an object representing a running object registered with 

OLE

Args:

      cls(typing.Any):The IID for the program.  As for all CLSID's in Python, a "program.name" or IID format string may be used, or a real PyIID object.

Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def GetClassFile(fileName:'typing.Any') -> 'win32typing.PyIID':
    """
    Supplies the CLSID associated with the given filename.

Args:

      fileName(typing.Any):The filename for which you are requesting the associated CLSID.

Returns:

      win32typing.PyIID
        
    """
    pass
        

def GetFacilityString(scode:'typing.Any') -> 'str':
    """
    Returns the facility string, given an OLE scode.

Args:

      scode(typing.Any):The OLE error code for the facility string requested.

Returns:

      str
        
    """
    pass
        

def GetRecordFromGuids(iid:'win32typing.PyIID',verMajor:'typing.Any',verMinor:'typing.Any',lcid:'typing.Any',infoIID:'win32typing.PyIID',data:'typing.Any'=None) -> 'typing.Any':
    """
    Creates a new record object from the given GUIDs

Args:

      iid(win32typing.PyIID):The GUID of the type library
      verMajor(typing.Any):The major version number of the type lib.
      verMinor(typing.Any):The minor version number of the type lib.
      lcid(typing.Any):The LCID of the type lib.
      infoIID(win32typing.PyIID):The GUID of the record info in the library
      data(typing.Any):The raw data to initialize the record with.

Returns:

      typing.Any
        
    """
    pass
        

def GetRecordFromTypeInfo(TypeInfo:'win32typing.PyITypeInfo') -> 'typing.Any':
    """
    None

Args:

      TypeInfo(win32typing.PyITypeInfo):The type information to be converted into a PyRecord objectCommentsThis function will fail if the specified type info does not have a guid defined

Returns:

      typing.Any
        
    """
    pass
        

def GetRunningObjectTable(reserved:'typing.Any'=0) -> 'win32typing.PyIRunningObjectTable':
    """
    None

Args:

      reserved(typing.Any):A reserved parameter.  Should be zero unless you have inside information that I don't!

Returns:

      win32typing.PyIRunningObjectTable
        
    """
    pass
        

def GetScodeString(scode:'typing.Any') -> 'str':
    """
    Returns the string for an OLE scode (HRESULT)

Args:

      scode(typing.Any):The OLE error code for the scode string requested.CommentsThis will obtain the COM Error message for a given HRESULT. Internally, PythonCOM uses this function to obtain the description when a com_error COM Exception is raised.

Returns:

      str
        
    """
    pass
        

def GetScodeRangeString(scode:'typing.Any') -> 'str':
    """
    Returns the scode range string, given an OLE scode.

Args:

      scode(typing.Any):An OLE error code to return the scode range string for.

Returns:

      str
        
    """
    pass
        

def GetSeverityString(scode:'typing.Any') -> 'str':
    """
    Returns the severity string, given an OLE scode.

Args:

      scode(typing.Any):The OLE error code for the severity string requested.

Returns:

      str
        
    """
    pass
        

def IsGatewayRegistered(iid:'win32typing.PyIID') -> 'typing.Any':
    """
    Returns true if a gateway has been registered for the given IID

Args:

      iid(win32typing.PyIID):IID of the interface.

Returns:

      typing.Any
        
    """
    pass
        

def LoadRegTypeLib(iid:'win32typing.PyIID',versionMajor:'typing.Any',versionMinor:'typing.Any',lcid:'typing.Any') -> 'win32typing.PyITypeLib':
    """
    Loads a registered type library.

Args:

      iid(win32typing.PyIID):The IID of the type library.
      versionMajor(typing.Any):The major version number of the library
      versionMinor(typing.Any):The minor version number of the library
      lcid(typing.Any):The locale ID to use.CommentsLoadRegTypeLib compares the requested version numbers against those found in the system registry, and takes one of the following actions: If one of the registered libraries exactly matches both the requested major and minor version numbers, then that type library is loaded.  If one or more registered type libraries exactly match the requested major version number, and has a greater minor version number than that requested, the one with the greatest minor version number is loaded.  If none of the registered type libraries exactly match the requested major version number (or if none of those that do exactly match the major version number also have a minor version number greater than or equal to the requested minor version number), then LoadRegTypeLib returns an error.

Returns:

      win32typing.PyITypeLib
        
    """
    pass
        

def LoadTypeLib(libFileName:'str') -> 'win32typing.PyITypeLib':
    """
    Loads a registered type library.

Args:

      libFileName(str):The path to the file containing the type information.

Returns:

      win32typing.PyITypeLib
        
    """
    pass
        

def MakePyFactory(iid:'win32typing.PyIID') -> 'win32typing.PyIClassFactory':
    """
    None

Args:

      iid(win32typing.PyIID):The IID of the object the class factory provides.

Returns:

      win32typing.PyIClassFactory
        
    """
    pass
        

def MkParseDisplayName(displayName:'str',bindCtx:'win32typing.PyIBindCtx'=None) -> 'typing.Tuple[win32typing.PyIMoniker, typing.Any, win32typing.PyIBindCtx]':
    """
    None

Args:

      displayName(str):The display name to parse
      bindCtx(win32typing.PyIBindCtx):The bind context object to use.CommentsIf a binding context is not provided, then one will be created. Any binding context created or passed in will be returned to the caller.

Returns:

      typing.Tuple[win32typing.PyIMoniker, typing.Any, win32typing.PyIBindCtx]
        
    """
    pass
        

def New(cls:'typing.Any') -> 'win32typing.PyIDispatch':
    """
    Create a new instance of an OLE automation server.

Args:

      cls(typing.Any):An identifier for the program.  Usually "program.item"CommentsThis is just a wrapper for the CoCreateInstance method. Specifically, this call is identical to: pythoncom.CoCreateInstance(cls, None, pythoncom.CLSCTX_SERVER, pythoncom.IID_IDispatch)

Returns:

      win32typing.PyIDispatch
        
    """
    pass
        

def ObjectFromAddress(address:'typing.Any',iid:'win32typing.PyIID') -> 'win32typing.PyIUnknown':
    """
    Returns a COM object given its address in memory.

Args:

      address(typing.Any):The address which holds a COM object
      iid(win32typing.PyIID):The IID to queryReturn ValueThis method is useful for applications which return objects via non-standard mechanisms - eg, Windows Explorer allows you to send a specific message to the explorer window and the result will be the address of an object Explorer implements. This method allows you to recover the object from that address.

Returns:

      win32typing.PyIUnknown:The IID to query
Return ValueThis method is useful for applications which return objects via non-standard 

mechanisms - eg, Windows Explorer allows you to send a specific message to the 

explorer window and the result will be the address of an object Explorer implements. 

This method allows you to recover the object from that address.

        
    """
    pass
        

def ObjectFromLresult(lresult:'typing.Any',iid:'win32typing.PyIID',wparm:'typing.Any') -> 'win32typing.PyIUnknown':
    """
    Retrieves a requested 

interface pointer for an object based on a previously generated object reference.

Args:

      lresult(typing.Any):
      iid(win32typing.PyIID):The IID to query
      wparm(typing.Any):

Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def OleInitialize() -> 'None':
    """
    None

Args:



Returns:

      None
        
    """
    pass
        

def OleGetClipboard() -> 'win32typing.PyIDataObject':
    """
    Retrieves a data object that you can use to access the contents 

of the clipboard.

Args:



Returns:

      win32typing.PyIDataObject
        
    """
    pass
        

def OleFlushClipboard() -> 'None':
    """
    None

Args:



Returns:

      None
        
    """
    pass
        

def OleIsCurrentClipboard(dataObj:'win32typing.PyIDataObject') -> 'typing.Union[typing.Any]':
    """
    Determines whether the data object pointer previously placed on 

the clipboard by the OleSetClipboard function is still on the clipboard.

Args:

      dataObj(win32typing.PyIDataObject):The data object to check

Returns:

      typing.Union[typing.Any]
        
    """
    pass
        

def OleSetClipboard(dataObj:'win32typing.PyIDataObject') -> 'None':
    """
    Places a pointer to a specific data object onto the clipboard. This makes the 

data object accessible to the OleGetClipboard function.

Args:

      dataObj(win32typing.PyIDataObject):The data object to place on the clipboard. This parameter can be None in which case the clipboard is emptied.

Returns:

      None
        
    """
    pass
        

def OleLoadFromStream(stream:'win32typing.PyIStream',iid:'win32typing.PyIID') -> 'None':
    """
    Load an object from an IStream.

Args:

      stream(win32typing.PyIStream):The stream to load the object from.
      iid(win32typing.PyIID):The IID if the interface to load.

Returns:

      None
        
    """
    pass
        

def OleSaveToStream(persist:'win32typing.PyIPersistStream',stream:'win32typing.PyIStream') -> 'None':
    """
    Save an object to an IStream.

Args:

      persist(win32typing.PyIPersistStream):The object to save
      stream(win32typing.PyIStream):The stream to save the object to.

Returns:

      None
        
    """
    pass
        

def OleLoad(storage:'win32typing.PyIStorage',iid:'win32typing.PyIID',site:'win32typing.PyIOleClientSite') -> 'None':
    """
    Loads into memory an object nested within a specified storage object.

Args:

      storage(win32typing.PyIStorage):The storage object from which to load
      iid(win32typing.PyIID):The IID if the interface to load.
      site(win32typing.PyIOleClientSite):The client site for the object.

Returns:

      None
        
    """
    pass
        

def ProgIDFromCLSID(clsid:'typing.Any') -> 'str':
    """
    Converts a CLSID to a progID.

Args:

      clsid(typing.Any):A CLSID (either in a string, or in an PyIID object)

Returns:

      str
        
    """
    pass
        

def PumpWaitingMessages() -> 'typing.Any':
    """
    Pumps all waiting messages for the current thread.

Args:



Returns:

      typing.Any:Search for PeekMessage and DispatchMessage at msdn, google or google groups.
Return ValueReturns 1 if a WM_QUIT message was received, else 0

        
    """
    pass
        

def PumpMessages() -> 'None':
    """
    Pumps all messages for the current thread until a WM_QUIT message.

Args:



Returns:

      None
        
    """
    pass
        

def QueryPathOfRegTypeLib(iid:'win32typing.PyIID',versionMajor:'typing.Any',versionMinor:'typing.Any',lcid:'typing.Any') -> 'str':
    """
    Retrieves the path of a registered type library.

Args:

      iid(win32typing.PyIID):The IID of the type library.
      versionMajor(typing.Any):The major version number of the library
      versionMinor(typing.Any):The minor version number of the library
      lcid(typing.Any):The locale ID to use.

Returns:

      str
        
    """
    pass
        

def ReadClassStg(storage:'win32typing.PyIStorage') -> 'win32typing.PyIID':
    """
    Reads a CLSID from a storage object.

Args:

      storage(win32typing.PyIStorage):The storage to read the CLSID from.

Returns:

      win32typing.PyIID
        
    """
    pass
        

def ReadClassStm(Stm:'win32typing.PyIStream') -> 'win32typing.PyIID':
    """
    Retrieves the CLSID from a stream

Args:

      Stm(win32typing.PyIStream):An IStream interface

Returns:

      win32typing.PyIID
        
    """
    pass
        

def RegisterTypeLib(typelib:'win32typing.PyITypeLib',fullPath:'str',lcid:'typing.Any',helpDir:'str'=None) -> 'None':
    """
    Adds information about a type library to the system registry.

Args:

      typelib(win32typing.PyITypeLib):The type library being registered.
      fullPath(str):Fully qualified path specification for the type library being registered
      lcid(typing.Any):The locale ID to use.CommentsThis function can be used during application initialization to register the application's type library correctly. When RegisterTypeLib is called to register a type library, both the minor and major version numbers are registered in hexadecimal.  In addition to filling in a complete registry entry under the type library key, RegisterTypeLib adds entries for each of the dispinterfaces and Automation-compatible interfaces, including dual interfaces. This information is required to create instances of these interfaces. Coclasses are not registered (that is, RegisterTypeLib does not write any values to the CLSID key of the coclass).
      helpDir(str):Directory in which the Help file for the library being registered can be found. Can be None.

Returns:

      None
        
    """
    pass
        

def UnRegisterTypeLib(iid:'win32typing.PyIID',versionMajor:'typing.Any',versionMinor:'typing.Any',lcid:'typing.Any',syskind:'typing.Any') -> 'str':
    """
    Unregister a Type Library.

Args:

      iid(win32typing.PyIID):The IID of the type library.
      versionMajor(typing.Any):The major version number of the library
      versionMinor(typing.Any):The minor version number of the library
      lcid(typing.Any):The locale ID to use.
      syskind(typing.Any):The target operating system.CommentsRemoves type library information from the system registry. Use this API to allow applications to properly uninstall themselves. In-process objects typically call this API from DllUnregisterServer.

Returns:

      str
        
    """
    pass
        

def RegisterActiveObject(obUnknown:'win32typing.PyIUnknown',clsid:'win32typing.PyIID',flags:'typing.Any') -> 'typing.Any':
    """
    Register an object as the active object for its class

Args:

      obUnknown(win32typing.PyIUnknown):The object to register.
      clsid(win32typing.PyIID):The CLSID for the object
      flags(typing.Any):Flags to use.Return ValueThe result is a handle which should be pass to pythoncom::RevokeActiveObject

Returns:

      typing.Any:Flags to use.Return ValueThe result is a handle which should be pass to pythoncom::RevokeActiveObject

        
    """
    pass
        

def RevokeActiveObject(handle:'typing.Any') -> 'None':
    """
    Ends an objects status as active.

Args:

      handle(typing.Any):A handle obtained from pythoncom::RegisterActiveObject

Returns:

      None
        
    """
    pass
        

def RegisterDragDrop(hwnd:'int',dropTarget:'win32typing.PyIDropTarget') -> 'None':
    """
    None

Args:

      hwnd(int):Handle to a window
      dropTarget(win32typing.PyIDropTarget):Object that implements the IDropTarget interface

Returns:

      None
        
    """
    pass
        

def RevokeDragDrop(hwnd:'int') -> 'None':
    """
    Revokes the registration of the 

specified application window as a potential target for OLE drag-and-drop 

operations.

Args:

      hwnd(int):Handle to a window registered as an OLE drop target.

Returns:

      None
        
    """
    pass
        

def DoDragDrop() -> 'None':
    """
    Carries out an OLE drag and drop operation.

Args:



Returns:

      None
        
    """
    pass
        

def StgCreateDocfile(name:'str',mode:'typing.Any',reserved:'typing.Any'=0) -> 'win32typing.PyIStorage':
    """
    None

Args:

      name(str):the path of the compound file to create. It is passed uninterpreted to the file system. This can be a relative name or None.  If None, a temporary stream is created.
      mode(typing.Any):Specifies the access mode used to open the storage.
      reserved(typing.Any):A reserved value

Returns:

      win32typing.PyIStorage
        
    """
    pass
        

def StgCreateDocfileOnILockBytes(lockBytes:'win32typing.PyILockBytes',mode:'typing.Any',reserved:'typing.Any'=0) -> 'win32typing.PyIStorage':
    """
    None

Args:

      lockBytes(win32typing.PyILockBytes):The PyILockBytes interface on the underlying byte array object on which to create a compound file.
      mode(typing.Any):Specifies the access mode used to open the storage.
      reserved(typing.Any):A reserved value

Returns:

      win32typing.PyIStorage
        
    """
    pass
        

def StgOpenStorageOnILockBytes(lockBytes:'win32typing.PyILockBytes',stgPriority:'win32typing.PyIStorage',snbExclude:'typing.Any'=None,reserved:'typing.Any'=0) -> 'win32typing.PyIStorage':
    """
    None

Args:

      lockBytes(win32typing.PyILockBytes):The PyILockBytes interface on the underlying byte array object on which to open an existing storage object.
      stgPriority(win32typing.PyIStorage):Usually None, or another parent storage.
      snbExclude(typing.Any):Not yet supported - must be None
      reserved(typing.Any):A reserved value

Returns:

      win32typing.PyIStorage
        
    """
    pass
        

def StgIsStorageFile(name:'str') -> 'typing.Any':
    """
    Indicates whether a particular disk file contains a storage object.

Args:

      name(str):The path to the file to check.Return ValueThe return value is 1 if a storage file, else 0.  This method will also raise com_error if the StgIsStorageFile function returns a failure HRESULT.

Returns:

      typing.Any:The path to the file to check.Return ValueThe return value is 1 if a storage file, else 0.  This 

method will also raise com_error if the StgIsStorageFile function 

returns a failure HRESULT.

        
    """
    pass
        

def STGMEDIUM() -> 'win32typing.PySTGMEDIUM':
    """
    Creates a new STGMEDIUM object

Args:



Returns:

      win32typing.PySTGMEDIUM
        
    """
    pass
        

def StgOpenStorage(name:'str',other:'win32typing.PyIStorage',mode:'typing.Any',snbExclude:'typing.Any'=None,reserved:'typing.Any'=0) -> 'win32typing.PyIStorage':
    """
    Opens an existing root storage object in the file system.

Args:

      name(str):Name of the stream, or possibly None if storageOther is non None.
      other(win32typing.PyIStorage):Usually None, or another parent storage.
      mode(typing.Any):Specifies the access mode used to open the storage.  A combination of the storagecon.STGM_* constants.
      snbExclude(typing.Any):Not yet supported - must be None
      reserved(typing.Any):A reserved value

Returns:

      win32typing.PyIStorage
        
    """
    pass
        

def StgOpenStorageEx(Name:'str',Mode:'typing.Any',stgfmt:'typing.Any',Attrs:'typing.Any',riid:'win32typing.PyIID',StgOptions:'typing.Any'=None) -> 'win32typing.PyIStorage':
    """
    Advanced version of StgOpenStorage, win2k or better

Args:

      Name(str):Name of the stream or file to open
      Mode(typing.Any):Access mode, combination of storagecon.STGM_* flags
      stgfmt(typing.Any):Storage format (STGFMT_STORAGE,STGFMT_FILE,STGFMT_ANY, or STGFMT_DOCFILE)
      Attrs(typing.Any):File flags and attributes, only used with STGFMT_DOCFILE
      riid(win32typing.PyIID):Interface id to return, IStorage or IPropertySetStorage
      StgOptions(typing.Any):Dictionary representing STGOPTIONS struct (only used with STGFMT_DOCFILE)CommentsRequires Win2k or laterAccepts keyword args

Returns:

      win32typing.PyIStorage
        
    """
    pass
        

def StgCreateStorageEx(Name:'str',Mode:'typing.Any',stgfmt:'typing.Any',Attrs:'typing.Any',riid:'win32typing.PyIID',StgOptions:'typing.Any'=None,SecurityDescriptor:'win32typing.PySECURITY_DESCRIPTOR'=None) -> 'win32typing.PyIStorage':
    """
    Creates a new structured storage file or property set

Args:

      Name(str):Name of the stream or file to open
      Mode(typing.Any):Access mode, combination of storagecon.STGM_* flags
      stgfmt(typing.Any):Storage format, storagecon.STGFMT_*
      Attrs(typing.Any):File flags and attributes, only used with STGFMT_DOCFILE
      riid(win32typing.PyIID):Interface id to return, IStorage or IPropertySetStorage
      StgOptions(typing.Any):Dictionary representing STGOPTIONS struct (only used with STGFMT_DOCFILE)
      SecurityDescriptor(win32typing.PySECURITY_DESCRIPTOR):Specifies security for the new file. Must be None on Windows XP.CommentsRequires Win2k or laterAccepts keyword args

Returns:

      win32typing.PyIStorage
        
    """
    pass
        

def TYPEATTR() -> 'win32typing.TYPEATTR':
    """
    Creates a new TYPEATTR object

Args:



Returns:

      win32typing.TYPEATTR
        
    """
    pass
        

def VARDESC() -> 'win32typing.VARDESC':
    """
    Creates a new VARDESC object

Args:



Returns:

      win32typing.VARDESC
        
    """
    pass
        

def WrapObject(ob:'typing.Any',gatewayIID:'win32typing.PyIID',interfaceIID:'win32typing.PyIID') -> 'win32typing.PyIUnknown':
    """
    Wraps a Python instance in a gateway object.

Args:

      ob(typing.Any):The object to wrap.
      gatewayIID(win32typing.PyIID):The IID of the gateway object to create (ie, the interface of the server object wrapped by the return value)
      interfaceIID(win32typing.PyIID):The IID of the interface object to create (ie, the interface of the returned object)Return ValueNote that there are 2 objects created by this call - a gateway (server) object, suitable for use by other external COM clients/hosts, as well as the returned Python interface (client) object, which maps to the new gateway. There are some unusual cases where the 2 IID parameters will not be identical. If you need to do this, you should know exactly what you are doing, and why!

Returns:

      win32typing.PyIUnknown:The IID of the interface object to create (ie, the interface of the 

returned object)
Return ValueNote that there are 2 objects created by this call - a gateway (server) object, suitable for 

use by other external COM clients/hosts, as well as the returned Python interface (client) object, which 

maps to the new gateway. 

There are some unusual cases where the 2 IID parameters will not be identical. 

If you need to do this, you should know exactly what you are doing, and why!

        
    """
    pass
        

def WriteClassStg(storage:'win32typing.PyIStorage',iid:'win32typing.PyIID') -> 'None':
    """
    Writes a CLSID to a storage object

Args:

      storage(win32typing.PyIStorage):Storage object into which CLSID will be written.
      iid(win32typing.PyIID):The IID to write

Returns:

      None
        
    """
    pass
        

def WriteClassStm(Stm:'win32typing.PyIStream',clsid:'win32typing.PyIID') -> 'None':
    """
    Writes a CLSID to a stream.

Args:

      Stm(win32typing.PyIStream):An IStream interface
      clsid(win32typing.PyIID):The IID to write

Returns:

      None
        
    """
    pass
        

def UnwrapObject(ob:'win32typing.PyIUnknown') -> 'win32typing.PyIDispatch':
    """
    Unwraps a Python instance in a gateway object.

Args:

      ob(win32typing.PyIUnknown):The object to unwrap.CommentsIf the object is not a PythonCOM object, then ValueError is raised.

Returns:

      win32typing.PyIDispatch
        
    """
    pass
        

def FmtIdToPropStgName(fmtid:'win32typing.PyIID') -> 'typing.Any':
    """
    Converts a FMTID to its stream name

Args:

      fmtid(win32typing.PyIID):Format id - a property storage GUID (FMTID_* IIDs)

Returns:

      typing.Any
        
    """
    pass
        

def PropStgNameToFmtId(Name:'typing.Union[typing.Any, str]') -> 'win32typing.PyIID':
    """
    Converts a property set name to its format id (GUID)

Args:

      Name(typing.Union[typing.Any, str]):Storage stream name

Returns:

      win32typing.PyIID
        
    """
    pass
        

def CoGetCallContext(riid:'win32typing.PyIID') -> 'win32typing.PyIServerSecurity':
    """
    Creates interfaces used to access client security 

requirements and perform impersonation

Args:

      riid(win32typing.PyIID):The interface to create, IID_IServerSecurity or IID_ISecurityCallContextCommentsISecurityCallContext will only be available for a server that uses role-based security

Returns:

      win32typing.PyIServerSecurity
        
    """
    pass
        

def CoGetObjectContext(riid:'win32typing.PyIID') -> 'win32typing.PyIContext':
    """
    Creates an interface to interact with the context of the 

current object

Args:

      riid(win32typing.PyIID):The interface to returnCommentsRequires Win2k or laterCOM applications can use this function to create IComThreadingInfo, IContext, or IContextCallback COM+ applications may also create IObjectContext, IObjectContextInfo, IObjectContextActivity, or IContextState

Returns:

      win32typing.PyIContext
        
    """
    pass
        

def CoGetCancelObject(riid:'win32typing.PyIID',ThreadID:'typing.Any'=0) -> 'win32typing.PyICancelMethodCalls':
    """
    Retrieves an interface used to cancel a pending call

Args:

      riid(win32typing.PyIID):The interface to returnCommentsRequires Win2k or later
      ThreadID(typing.Any):Id of thread with pending call, or 0 for current thread

Returns:

      win32typing.PyICancelMethodCalls
        
    """
    pass
        

def CoSetCancelObject(Unk:'win32typing.PyIUnknown') -> 'None':
    """
    None

Args:

      Unk(win32typing.PyIUnknown):An interface that support ICancelMethodCalls, can be None to unregister current cancel objectCommentsRequires Win2k or later

Returns:

      None
        
    """
    pass
        

def CoEnableCallCancellation() -> 'None':
    """
    Enables call cancellation for synchronous calls on the current thread

Args:



Returns:

      None
        
    """
    pass
        

def CoDisableCallCancellation() -> 'None':
    """
    Disables call cancellation for synchronous calls on the current thread

Args:



Returns:

      None
        
    """
    pass
        


__all__=['', 'CreateEnvironmentBlock', 'DeleteProfile', 'ExpandEnvironmentStringsForUser', 'GetAllUsersProfileDirectory', 'GetDefaultUserProfileDirectory', 'GetEnvironmentStrings', 'GetProfilesDirectory', 'GetProfileType', 'GetUserProfileDirectory', 'LoadUserProfile', 'UnloadUserProfile']
import typing
import win32typing
"""Wraps functions for dealing with user profiles"""


def CreateEnvironmentBlock(Token:'int',Inherit:'typing.Any') -> 'typing.Any':
    """
    Retrieves environment variables for a user

Args:

      Token(int):User token as returned by win32security::LogonUser, use None to retrieve system variables only
      Inherit(typing.Any):Indicates if environment of current process should be inherited

Returns:

      typing.Any
        
    """
    pass
        

def DeleteProfile(SidString:'str',ProfilePath:'str'=None,ComputerName:'str'=None) -> 'None':
    """
    Remove profile for a user identified by string SID from specified machine.

Args:

      SidString(str):String representation of user's Sid.  See win32security::ConvertSidToStringSid.
      ProfilePath(str):Profile directory, value queried from registry if not specified
      ComputerName(str):Name of computer from which to delete profile, local machine assumed if not specified

Returns:

      None
        
    """
    pass
        

def ExpandEnvironmentStringsForUser(Token:'int',Src:'str') -> 'str':
    """
    Replaces environment variables in a string with 

per-user values

Args:

      Token(int):The logon token for a user.  Use None for system variables.
      Src(str):String containing environment variables enclosed in % signs

Returns:

      str
        
    """
    pass
        

def GetAllUsersProfileDirectory() -> 'str':
    """
    Retrieve All Users profile path

Args:



Returns:

      str
        
    """
    pass
        

def GetDefaultUserProfileDirectory() -> 'str':
    """
    Retrieve Default user profile

Args:



Returns:

      str
        
    """
    pass
        

def GetEnvironmentStrings() -> 'typing.Any':
    """
    Retrieves environment variables for current process

Args:



Returns:

      typing.Any
        
    """
    pass
        

def GetProfilesDirectory() -> 'str':
    """
    Retrieves directory where user profiles are stored

Args:



Returns:

      str
        
    """
    pass
        

def GetProfileType() -> 'typing.Any':
    """
    Returns type of current user's profile

Args:



Returns:

      typing.Any:win32profile.GetProfileType

int = GetProfileType()Returns type of current user's profile
Return ValueReturns a combination of PT_* flags

        
    """
    pass
        

def GetUserProfileDirectory(Token:'int') -> 'str':
    """
    Returns profile directory for a logon token

Args:

      Token(int):User token as returned by win32security::LogonUser

Returns:

      str
        
    """
    pass
        

def LoadUserProfile(hToken:'int',ProfileInfo:'win32typing.PyPROFILEINFO') -> 'win32typing.PyHKEY':
    """
    Loads user settings into registry

Args:

      hToken(int):Logon token as returned by win32security::LogonUser, win32security::OpenThreadToken, etc
      ProfileInfo(win32typing.PyPROFILEINFO):Dictionary representing a PROFILEINFO structureCommentsSE_BACKUP_NAME and SE_RESTORE_NAME privs are required, but do not have to be enabledReturn ValueReturns a handle to user's registry key.

Returns:

      win32typing.PyHKEY:Dictionary representing a PROFILEINFO structureComments

SE_BACKUP_NAME and SE_RESTORE_NAME privs are required, but do not have to be enabled
Return ValueReturns a handle to user's registry key.

        
    """
    pass
        

def UnloadUserProfile(Token:'int',Profile:'win32typing.PyHKEY') -> 'None':
    """
    None

Args:

      Token(int):Logon token as returned by win32security::LogonUser, win32security::OpenProcessToken, etc
      Profile(win32typing.PyHKEY):Registry handle as returned by win32profile::LoadUserProfile

Returns:

      None
        
    """
    pass
        


__all__=['', 'OleCreate', 'OleLoadPicture', 'OleLoadPicturePath', 'OleSetContainedObject', 'OleTranslateAccelerator', 'EMBDHLP_CREATENOW', 'EMBDHLP_DELAYCREATE', 'EMBDHLP_INPROC_HANDLER', 'EMBDHLP_INPROC_SERVER', 'OLECLOSE_NOSAVE', 'OLECLOSE_PROMPTSAVE', 'OLECLOSE_SAVEIFDIRTY', 'OLECMDF_ENABLED', 'OLECMDF_LATCHED', 'OLECMDF_NINCHED', 'OLECMDF_SUPPORTED', 'OLECMDTEXTF_NAME', 'OLECMDTEXTF_NONE', 'OLECMDTEXTF_STATUS', 'OLECREATE_LEAVERUNNING', 'OLEIVERB_DISCARDUNDOSTATE', 'OLEIVERB_HIDE', 'OLEIVERB_INPLACEACTIVATE', 'OLEIVERB_OPEN', 'OLEIVERB_PRIMARY', 'OLEIVERB_SHOW', 'OLEIVERB_UIACTIVATE']
import typing
import win32typing
"""A module, encapsulating the ActiveX Control interfaces"""


def OleCreate(clsid:'typing.Any',clsid1:'typing.Any',obCLSID:'win32typing.PyIID',obIID:'win32typing.PyIID',renderopt:'typing.Any',obFormatEtc:'typing.Any',obOleClientSite:'win32typing.PyIOleClientSite',obStorage:'win32typing.PyIStorage') -> 'win32typing.PyIOleObject':
    """
    Creates a new embedded object identified by a CLSID.

Args:

      clsid(typing.Any):A CLSID in string or native format
      clsid1(typing.Any):A IID in string or native format
      obCLSID(win32typing.PyIID):The PyIID CLSID for the OLE object to create.
      obIID(win32typing.PyIID):The PyIID for the interface to return.
      renderopt(typing.Any):The DWORD renderopt for redering the Display.
      obFormatEtc(typing.Any):The FORMATETC structure.
      obOleClientSite(win32typing.PyIOleClientSite):The PyIOleClientSite interface to the container.
      obStorage(win32typing.PyIStorage):The PyIStorage interface.

Returns:

      win32typing.PyIOleObject
        
    """
    pass
        

def OleLoadPicture(stream:'win32typing.PyIStream',size:'typing.Any',runMode:'typing.Any',arg:'win32typing.PyIID',arg1:'win32typing.PyIID') -> 'win32typing.PyIUnknown':
    """
    Creates a new picture object and initializes it from the contents 

of a stream.

Args:

      stream(win32typing.PyIStream):The stream that contains picture's data.
      size(typing.Any):Number of bytes read from the stream
      runMode(typing.Any):The opposite of the initial value of the KeepOriginalFormat property. If TRUE, KeepOriginalFormat is set to FALSE and vice-versa.
      arg(win32typing.PyIID):The identifier of the interface describing the type of interface pointer to return
      arg1(win32typing.PyIID):The IID to use for the return object - use only if pythoncom does not support the native interface requested.

Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def OleLoadPicturePath(url_or_path:'typing.Union[typing.Any, str]',unk:'typing.Any',reserved:'typing.Any',clr:'typing.Any',arg:'win32typing.PyIID',arg1:'win32typing.PyIID') -> 'win32typing.PyIUnknown':
    """
    Creates a new picture object and initializes it from the 

contents of a stream.

Args:

      url_or_path(typing.Union[typing.Any, str]):The path or url to the file you want to open.
      unk(typing.Any):The IUnknown for COM aggregation.
      reserved(typing.Any):reserved
      clr(typing.Any):The color you want to reserve to be transparent.
      arg(win32typing.PyIID):The identifier of the interface describing the type of interface pointer to return
      arg1(win32typing.PyIID):The IID to use for the return object - use only if pythoncom does not support the native interface requested.

Returns:

      win32typing.PyIUnknown
        
    """
    pass
        

def OleSetContainedObject(unk:'win32typing.PyIUnknown',fContained:'typing.Any') -> 'None':
    """
    Notifies an object embedded in an OLE container to ensure correct 

reference.

Args:

      unk(win32typing.PyIUnknown):The object
      fContained(typing.Any):

Returns:

      None
        
    """
    pass
        

def OleTranslateAccelerator(frame:'win32typing.PyIOleInPlaceFrame',frame_info:'typing.Any',msg:'win32typing.PyMSG') -> 'None':
    """
    Called by the object application, allows an object's container to 

translate accelerators according to the container's accelerator table.

Args:

      frame(win32typing.PyIOleInPlaceFrame):frame to send keystrokes to.
      frame_info(typing.Any):
      msg(win32typing.PyMSG):

Returns:

      None
        
    """
    pass
        
EMBDHLP_CREATENOW = ...
EMBDHLP_DELAYCREATE = ...
EMBDHLP_INPROC_HANDLER = ...
EMBDHLP_INPROC_SERVER = ...
OLECLOSE_NOSAVE = ...
OLECLOSE_PROMPTSAVE = ...
OLECLOSE_SAVEIFDIRTY = ...
OLECMDF_ENABLED = ...
OLECMDF_LATCHED = ...
OLECMDF_NINCHED = ...
OLECMDF_SUPPORTED = ...
OLECMDTEXTF_NAME = ...
OLECMDTEXTF_NONE = ...
OLECMDTEXTF_STATUS = ...
OLECREATE_LEAVERUNNING = ...
OLEIVERB_DISCARDUNDOSTATE = ...
OLEIVERB_HIDE = ...
OLEIVERB_INPLACEACTIVATE = ...
OLEIVERB_OPEN = ...
OLEIVERB_PRIMARY = ...
OLEIVERB_SHOW = ...
OLEIVERB_UIACTIVATE = ...



__all__=['', 'OpenThemeData', 'CloseThemeData', 'DrawThemeBackground', 'DrawThemeText', 'GetThemeBackgroundContentRect', 'GetThemeBackgroundExtent', 'IsThemeActive', 'IsAppThemed', 'GetWindowTheme', 'EnableThemeDialogTexture', 'IsThemeDialogTextureEnabled', 'GetThemeAppProperties', 'EnableTheming', 'SetWindowTheme', 'GetCurrentThemeName', 'ETDT_DISABLE', 'ETDT_ENABLE', 'ETDT_ENABLETAB', 'ETDT_USETABTEXTURE']
import typing
import win32typing
""""""


def OpenThemeData(hwnd:'int',pszClassList:'str') -> 'win32typing.PyHTHEME':
    """
    None

Args:

      hwnd(typing.Any):Window handle of the control/window to be themed
      pszClassList(str):Class name (or list of names) to match to theme data section.  if the list contains more than one name, the names are tested one at a time for a match. If a match is found, OpenThemeData() returns a theme handle associated with the matching class. This param is a list (instead of just a single class name) to provide the class an opportunity to get the "best" match between the class and the current theme.  For example, a button might pass L"OkButton, Button" if its ID=ID_OK.  If the current theme has an entry for OkButton, that will be used.  Otherwise, we fall back on the normal Button entry.

Returns:

      win32typing.PyHTHEME
        
    """
    pass
        

def CloseThemeData(hTheme:'win32typing.PyHTHEME') -> 'None':
    """
    Closes the theme data handle.  This should be done 

when the window being themed is destroyed or 

whenever a WM_THEMECHANGED msg is received 

(followed by an attempt to create a new Theme data 

handle).

Args:

      hTheme(win32typing.PyHTHEME):Open theme data handle (returned from prior call to OpenThemeData() API).

Returns:

      None
        
    """
    pass
        

def DrawThemeBackground(hTheme:'win32typing.PyHTHEME',hdc:'typing.Any',iPartId:'typing.Any',iStateId:'typing.Any',pRect:'typing.Any',pClipRect:'typing.Any') -> 'None':
    """
    Draws the theme-specified border and fill for 

the "iPartId" and "iStateId".  This could be 

based on a bitmap file, a border and fill, or 

other image description.

Args:

      hTheme(win32typing.PyHTHEME):theme data handle
      hdc(typing.Any):HDC to draw into
      iPartId(typing.Any):part number to draw
      iStateId(typing.Any):state number (of the part) to draw
      pRect(typing.Any):defines the size/location of the part
      pClipRect(typing.Any):optional clipping rect (don't draw outside it)

Returns:

      None
        
    """
    pass
        

def DrawThemeText(hTheme:'win32typing.PyHTHEME',hdc:'typing.Any',iPartId:'typing.Any',iStateId:'typing.Any',pszText:'str',dwCharCount:'typing.Any',dwTextFlags:'typing.Any',dwTextFlags2:'typing.Any',pRect:'typing.Any') -> 'None':
    """
    Draws the text using the theme-specified 

color and font for the "iPartId" and "iStateId".

Args:

      hTheme(win32typing.PyHTHEME):theme data handle
      hdc(typing.Any):HDC to draw into
      iPartId(typing.Any):part number to draw
      iStateId(typing.Any):state number (of the part) to draw
      pszText(str):actual text to draw
      dwCharCount(typing.Any):number of chars to draw (-1 for all)
      dwTextFlags(typing.Any):same as DrawText() "uFormat" param
      dwTextFlags2(typing.Any):additional drawing options
      pRect(typing.Any):defines the size/location of the part

Returns:

      None
        
    """
    pass
        

def GetThemeBackgroundContentRect(hTheme:'win32typing.PyHTHEME',hdc:'typing.Any',iPartId:'typing.Any',iStateId:'typing.Any',pBoundingRect:'typing.Any') -> 'typing.Any':
    """
    Gets the size of the content for the theme-defined 

background.  This is usually the area inside the borders or Margins.

Args:

      hTheme(win32typing.PyHTHEME):theme data handle
      hdc(typing.Any):(optional) device content to be used for drawing
      iPartId(typing.Any):part number to draw
      iStateId(typing.Any):state number (of the part) to draw
      pBoundingRect(typing.Any):the outer RECT of the part being drawnReturn ValueThe result is a rect with the content area

Returns:

      typing.Any:the outer RECT of the part being drawnReturn ValueThe result is a rect with the content area

        
    """
    pass
        

def GetThemeBackgroundExtent(hTheme:'win32typing.PyHTHEME',hdc:'typing.Any',iPartId:'typing.Any',iStateId:'typing.Any',pContentRect:'typing.Any') -> 'typing.Any':
    """
    Calculates the size/location of the theme- 

specified background based on the "pContentRect".

Args:

      hTheme(win32typing.PyHTHEME):theme data handle
      hdc(typing.Any):(optional) device content to be used for drawing
      iPartId(typing.Any):part number to draw
      iStateId(typing.Any):state number (of the part) to draw
      pContentRect(typing.Any):RECT that defines the content areaReturn ValueResult is a rect with the overall size/location of part

Returns:

      typing.Any:RECT that defines the content areaReturn ValueResult is a rect with the overall size/location of part

        
    """
    pass
        

def IsThemeActive() -> 'typing.Any':
    """
    None

Args:



Returns:

      typing.Any
        
    """
    pass
        

def IsAppThemed() -> 'typing.Any':
    """
    Returns True if a theme is active and available to 

the current process

Args:



Returns:

      typing.Any
        
    """
    pass
        

def GetWindowTheme(hwnd:'int') -> 'win32typing.PyHTHEME':
    """
    If window is themed, returns its most recent 

HTHEME from OpenThemeData() - otherwise, returns NULL.

Args:

      hwnd(typing.Any):The window to get the HTHEME of

Returns:

      win32typing.PyHTHEME
        
    """
    pass
        

def EnableThemeDialogTexture(hdlg:'typing.Any',dwFlags:'typing.Any') -> 'None':
    """
    Enables/disables dialog background theme. 

This method can be used to 

tailor dialog compatibility with child windows and controls that 

may or may not coordinate the rendering of their client area backgrounds 

with that of their parent dialog in a manner that supports seamless 

background texturing.

Args:

      hdlg(typing.Any):The window handle of the target dialog
      dwFlags(typing.Any):ETDT_ENABLE to enable the theme-defined dialog background texturing, ETDT_DISABLE to disable background texturing, ETDT_ENABLETAB to enable the theme-defined background texturing using the Tab texture

Returns:

      None
        
    """
    pass
        

def IsThemeDialogTextureEnabled(hdlg:'typing.Any') -> 'typing.Any':
    """
    Reports whether the dialog supports background texturing.

Args:

      hdlg(typing.Any):The window handle of the target dialog

Returns:

      typing.Any
        
    """
    pass
        

def GetThemeAppProperties() -> 'typing.Any':
    """
    Returns the app property flags that control theming

Args:



Returns:

      typing.Any
        
    """
    pass
        

def EnableTheming(fEnable:'typing.Any') -> 'None':
    """
    Enables or disables themeing for the current user 

in the current and future sessions.

Args:

      fEnable(typing.Any):if False, disable theming & turn themes off. if True, enable themeing and, if user previously had a theme active, make it active now.

Returns:

      None
        
    """
    pass
        

def SetWindowTheme(hwnd:'int',pszSubAppName:'typing.Union[str, typing.Any]',pszSubIdList:'typing.Union[str, typing.Any]') -> 'None':
    """
    Rredirects an existing Window to use a different 

section of the current theme information than its class normally asks for.

Args:

      hwnd(typing.Any):The handle of the window (cannot be 0)
      pszSubAppName(typing.Union[str, typing.Any]):App (group) name to use in place of the calling app's name.  If NULL, the actual calling app name will be used.
      pszSubIdList(typing.Union[str, typing.Any]):A semicolon separated list of class Id names to use in place of actual list passed by the window's class.  if NULL, the id list from the calling class is used.

Returns:

      None
        
    """
    pass
        

def GetCurrentThemeName() -> 'typing.Tuple[str, str, str]':
    """
    Get the name of the current theme in-use, the 

canonical color scheme name (not the display name) and the 

canonical size name (not the display name).

Args:



Returns:

      typing.Tuple[str, str, str]
        
    """
    pass
        
ETDT_DISABLE = ...
ETDT_ENABLE = ...
ETDT_ENABLETAB = ...
ETDT_USETABTEXTURE = ...



__all__=['', 'AssignProcessToJobObject', 'CreateJobObject', 'OpenJobObject', 'TerminateJobObject', 'UserHandleGrantAccess', 'IsProcessInJob', 'QueryInformationJobObject', 'SetInformationJobObject', 'JOB_OBJECT_ALL_ACCESS', 'JOB_OBJECT_ASSIGN_PROCESS', 'JOB_OBJECT_BASIC_LIMIT_VALID_FLAGS', 'JOB_OBJECT_EXTENDED_LIMIT_VALID_FLAGS', 'JOB_OBJECT_LIMIT_ACTIVE_PROCESS', 'JOB_OBJECT_LIMIT_AFFINITY', 'JOB_OBJECT_LIMIT_BREAKAWAY_OK', 'JOB_OBJECT_LIMIT_DIE_ON_UNHANDLED_EXCEPTION', 'JOB_OBJECT_LIMIT_JOB_MEMORY', 'JOB_OBJECT_LIMIT_JOB_TIME', 'JOB_OBJECT_LIMIT_KILL_ON_JOB_CLOSE', 'JOB_OBJECT_LIMIT_PRESERVE_JOB_TIME', 'JOB_OBJECT_LIMIT_PRIORITY_CLASS', 'JOB_OBJECT_LIMIT_PROCESS_MEMORY', 'JOB_OBJECT_LIMIT_PROCESS_TIME', 'JOB_OBJECT_LIMIT_SCHEDULING_CLASS', 'JOB_OBJECT_LIMIT_SILENT_BREAKAWAY_OK', 'JOB_OBJECT_LIMIT_VALID_FLAGS', 'JOB_OBJECT_LIMIT_WORKINGSET', 'JOB_OBJECT_MSG_ABNORMAL_EXIT_PROCESS', 'JOB_OBJECT_MSG_ACTIVE_PROCESS_LIMIT', 'JOB_OBJECT_MSG_ACTIVE_PROCESS_ZERO', 'JOB_OBJECT_MSG_END_OF_JOB_TIME', 'JOB_OBJECT_MSG_END_OF_PROCESS_TIME', 'JOB_OBJECT_MSG_EXIT_PROCESS', 'JOB_OBJECT_MSG_JOB_MEMORY_LIMIT', 'JOB_OBJECT_MSG_NEW_PROCESS', 'JOB_OBJECT_MSG_PROCESS_MEMORY_LIMIT', 'JOB_OBJECT_POST_AT_END_OF_JOB', 'JOB_OBJECT_QUERY', 'JOB_OBJECT_RESERVED_LIMIT_VALID_FLAGS', 'JOB_OBJECT_SECURITY_FILTER_TOKENS', 'JOB_OBJECT_SECURITY_NO_ADMIN', 'JOB_OBJECT_SECURITY_ONLY_TOKEN', 'JOB_OBJECT_SECURITY_RESTRICTED_TOKEN', 'JOB_OBJECT_SECURITY_VALID_FLAGS', 'JOB_OBJECT_SET_ATTRIBUTES', 'JOB_OBJECT_SET_SECURITY_ATTRIBUTES', 'JOB_OBJECT_TERMINATE', 'JOB_OBJECT_TERMINATE_AT_END_OF_JOB', 'JOB_OBJECT_UI_VALID_FLAGS', 'JOB_OBJECT_UILIMIT_ALL', 'JOB_OBJECT_UILIMIT_DESKTOP', 'JOB_OBJECT_UILIMIT_DISPLAYSETTINGS', 'JOB_OBJECT_UILIMIT_EXITWINDOWS', 'JOB_OBJECT_UILIMIT_GLOBALATOMS', 'JOB_OBJECT_UILIMIT_HANDLES', 'JOB_OBJECT_UILIMIT_NONE', 'JOB_OBJECT_UILIMIT_READCLIPBOARD', 'JOB_OBJECT_UILIMIT_SYSTEMPARAMETERS', 'JOB_OBJECT_UILIMIT_WRITECLIPBOARD', 'JobObjectAssociateCompletionPortInformation', 'JobObjectBasicAccountingInformation', 'JobObjectBasicAndIoAccountingInformation', 'JobObjectBasicLimitInformation', 'JobObjectBasicProcessIdList', 'JobObjectBasicUIRestrictions', 'JobObjectEndOfJobTimeInformation', 'JobObjectExtendedLimitInformation', 'JobObjectJobSetInformation', 'JobObjectSecurityLimitInformation', 'MaxJobObjectInfoClass']
import typing
import win32typing
"""An interface to the win32 Process and Thread API's, 

available in Windows 2000 and later."""


def AssignProcessToJobObject(hJob:'int',hProcess:'int') -> 'None':
    """
    Associates a process with an existing job object.

Args:

      hJob(int):
      hProcess(int):

Returns:

      None
        
    """
    pass
        

def CreateJobObject(jobAttributes:'win32typing.PySECURITY_ATTRIBUTES',name:'typing.Any') -> 'None':
    """
    Creates or opens a job object.

Args:

      jobAttributes(win32typing.PySECURITY_ATTRIBUTES):
      name(typing.Any):

Returns:

      None
        
    """
    pass
        

def OpenJobObject(desiredAccess:'typing.Any',inheritHandles:'typing.Any',name:'typing.Any') -> 'None':
    """
    Opens an existing job object.

Args:

      desiredAccess(typing.Any):
      inheritHandles(typing.Any):
      name(typing.Any):

Returns:

      None
        
    """
    pass
        

def TerminateJobObject(hJob:'int',exitCode:'typing.Any') -> 'None':
    """
    Terminates all processes currently associated with the job.

Args:

      hJob(int):
      exitCode(typing.Any):

Returns:

      None
        
    """
    pass
        

def UserHandleGrantAccess(hUserHandle:'int',hJob:'int',grant:'typing.Any') -> 'None':
    """
    Grants or denies access to a handle to a User object to a job that has a user-interface restriction.

Args:

      hUserHandle(int):
      hJob(int):
      grant(typing.Any):

Returns:

      None
        
    """
    pass
        

def IsProcessInJob(hProcess:'int',hJob:'int') -> 'typing.Any':
    """
    Determines if the process is running in the specified job.

Args:

      hProcess(int):Handle to a process
      hJob(int):Handle to a job, use None to check if process is part of any jobCommentsFunction is only available on WinXP and later

Returns:

      typing.Any
        
    """
    pass
        

def QueryInformationJobObject(Job:'int',JobObjectInfoClass:'typing.Any') -> 'typing.Any':
    """
    Retrieves limit and job state information from the job object.

Args:

      Job(int):Handle to a job, use None for job that calling process is part of
      JobObjectInfoClass(typing.Any):The type of data required, one of JobObject* valuesJobObjectInfoClassType of information returnedJobObjectBasicAccountingInformationReturns a dict representing a JOBOBJECT_BASIC_ACCOUNTING_INFORMATION structJobObjectBasicAndIoAccountingInformationReturns a dict representing a JOBOBJECT_BASIC_AND_IO_ACCOUNTING_INFORMATION structJobObjectBasicLimitInformationReturns a dict representing a JOBOBJECT_BASIC_LIMIT_INFORMATION structJobObjectExtendedLimitInformationReturns a dict representing a JOBOBJECT_EXTENDED_LIMIT_INFORMATION structJobObjectEndOfJobTimeInformationReturns a dict representing a JOBOBJECT_END_OF_JOB_TIME_INFORMATION structJobObjectBasicUIRestrictionsReturns a dict representing a JOBOBJECT_BASIC_UI_RESTRICTIONS structJobObjectBasicProcessIdListReturns a sequence of pids of processes assigned to the jobJobObjectJobSetInformationReturns a dict representing a JOBOBJECT_JOBSET_INFORMATION struct (not documented on MSDN)JobObjectSecurityLimitInformationJOBOBJECT_SECURITY_LIMIT_INFORMATION Not implementedJobObjectAssociateCompletionPortInformationJOBOBJECT_ASSOCIATE_COMPLETION_PORT Not implementedReturn ValueThe type of the returned information is dependent on the class requested

Returns:

      typing.Any:The type of data required, one of JobObject* values


JobObjectInfoClass


Type of information returned



JobObjectBasicAccountingInformationReturns a dict representing a JOBOBJECT_BASIC_ACCOUNTING_INFORMATION struct
JobObjectBasicAndIoAccountingInformationReturns a dict representing a JOBOBJECT_BASIC_AND_IO_ACCOUNTING_INFORMATION struct
JobObjectBasicLimitInformationReturns a dict representing a JOBOBJECT_BASIC_LIMIT_INFORMATION struct
JobObjectExtendedLimitInformationReturns a dict representing a JOBOBJECT_EXTENDED_LIMIT_INFORMATION struct
JobObjectEndOfJobTimeInformationReturns a dict representing a JOBOBJECT_END_OF_JOB_TIME_INFORMATION struct
JobObjectBasicUIRestrictionsReturns a dict representing a JOBOBJECT_BASIC_UI_RESTRICTIONS struct
JobObjectBasicProcessIdListReturns a sequence of pids of processes assigned to the job
JobObjectJobSetInformationReturns a dict representing a JOBOBJECT_JOBSET_INFORMATION struct (not documented on MSDN)
JobObjectSecurityLimitInformationJOBOBJECT_SECURITY_LIMIT_INFORMATION Not implemented
JobObjectAssociateCompletionPortInformationJOBOBJECT_ASSOCIATE_COMPLETION_PORT Not implemented
Return ValueThe type of the returned information is dependent on the class requested

        
    """
    pass
        

def SetInformationJobObject(Job:'int',JobObjectInfoClass:'typing.Any',JobObjectInfo:'typing.Any') -> 'None':
    """
    Sets quotas and limits for a job

Args:

      Job(int):Handle to a job
      JobObjectInfoClass(typing.Any):The type of data required, one of JobObject* values
      JobObjectInfo(typing.Any):Dictionary containing info to be set, as returned by win32job::QueryInformationJobObjectJobObjectInfoClassType of information to be setJobObjectBasicLimitInformationA JOBOBJECT_BASIC_LIMIT_INFORMATION dictJobObjectExtendedLimitInformationdict representing a JOBOBJECT_EXTENDED_LIMIT_INFORMATION structJobObjectEndOfJobTimeInformationdict representing a JOBOBJECT_END_OF_JOB_TIME_INFORMATION structJobObjectBasicUIRestrictionsdict representing a JOBOBJECT_BASIC_UI_RESTRICTIONS structJobObjectJobSetInformationInput is a JOBOBJECT_JOBSET_INFORMATION dict - Not implementedJobObjectSecurityLimitInformationInput is a JOBOBJECT_SECURITY_LIMIT_INFORMATION dict - Not implementedJobObjectAssociateCompletionPortInformationInput is a JOBOBJECT_ASSOCIATE_COMPLETION_PORT dict - Not implemented

Returns:

      None
        
    """
    pass
        
JOB_OBJECT_ALL_ACCESS = ...
JOB_OBJECT_ASSIGN_PROCESS = ...
JOB_OBJECT_BASIC_LIMIT_VALID_FLAGS = ...
JOB_OBJECT_EXTENDED_LIMIT_VALID_FLAGS = ...
JOB_OBJECT_LIMIT_ACTIVE_PROCESS = ...
JOB_OBJECT_LIMIT_AFFINITY = ...
JOB_OBJECT_LIMIT_BREAKAWAY_OK = ...
JOB_OBJECT_LIMIT_DIE_ON_UNHANDLED_EXCEPTION = ...
JOB_OBJECT_LIMIT_JOB_MEMORY = ...
JOB_OBJECT_LIMIT_JOB_TIME = ...
JOB_OBJECT_LIMIT_KILL_ON_JOB_CLOSE = ...
JOB_OBJECT_LIMIT_PRESERVE_JOB_TIME = ...
JOB_OBJECT_LIMIT_PRIORITY_CLASS = ...
JOB_OBJECT_LIMIT_PROCESS_MEMORY = ...
JOB_OBJECT_LIMIT_PROCESS_TIME = ...
JOB_OBJECT_LIMIT_SCHEDULING_CLASS = ...
JOB_OBJECT_LIMIT_SILENT_BREAKAWAY_OK = ...
JOB_OBJECT_LIMIT_VALID_FLAGS = ...
JOB_OBJECT_LIMIT_WORKINGSET = ...
JOB_OBJECT_MSG_ABNORMAL_EXIT_PROCESS = ...
JOB_OBJECT_MSG_ACTIVE_PROCESS_LIMIT = ...
JOB_OBJECT_MSG_ACTIVE_PROCESS_ZERO = ...
JOB_OBJECT_MSG_END_OF_JOB_TIME = ...
JOB_OBJECT_MSG_END_OF_PROCESS_TIME = ...
JOB_OBJECT_MSG_EXIT_PROCESS = ...
JOB_OBJECT_MSG_JOB_MEMORY_LIMIT = ...
JOB_OBJECT_MSG_NEW_PROCESS = ...
JOB_OBJECT_MSG_PROCESS_MEMORY_LIMIT = ...
JOB_OBJECT_POST_AT_END_OF_JOB = ...
JOB_OBJECT_QUERY = ...
JOB_OBJECT_RESERVED_LIMIT_VALID_FLAGS = ...
JOB_OBJECT_SECURITY_FILTER_TOKENS = ...
JOB_OBJECT_SECURITY_NO_ADMIN = ...
JOB_OBJECT_SECURITY_ONLY_TOKEN = ...
JOB_OBJECT_SECURITY_RESTRICTED_TOKEN = ...
JOB_OBJECT_SECURITY_VALID_FLAGS = ...
JOB_OBJECT_SET_ATTRIBUTES = ...
JOB_OBJECT_SET_SECURITY_ATTRIBUTES = ...
JOB_OBJECT_TERMINATE = ...
JOB_OBJECT_TERMINATE_AT_END_OF_JOB = ...
JOB_OBJECT_UI_VALID_FLAGS = ...
JOB_OBJECT_UILIMIT_ALL = ...
JOB_OBJECT_UILIMIT_DESKTOP = ...
JOB_OBJECT_UILIMIT_DISPLAYSETTINGS = ...
JOB_OBJECT_UILIMIT_EXITWINDOWS = ...
JOB_OBJECT_UILIMIT_GLOBALATOMS = ...
JOB_OBJECT_UILIMIT_HANDLES = ...
JOB_OBJECT_UILIMIT_NONE = ...
JOB_OBJECT_UILIMIT_READCLIPBOARD = ...
JOB_OBJECT_UILIMIT_SYSTEMPARAMETERS = ...
JOB_OBJECT_UILIMIT_WRITECLIPBOARD = ...
JobObjectAssociateCompletionPortInformation = ...
JobObjectBasicAccountingInformation = ...
JobObjectBasicAndIoAccountingInformation = ...
JobObjectBasicLimitInformation = ...
JobObjectBasicProcessIdList = ...
JobObjectBasicUIRestrictions = ...
JobObjectEndOfJobTimeInformation = ...
JobObjectExtendedLimitInformation = ...
JobObjectJobSetInformation = ...
JobObjectSecurityLimitInformation = ...
MaxJobObjectInfoClass = ...



__all__=['', 'WinHelp', 'HH_AKLINK', 'HH_FTS_QUERY', 'HH_POPUP', 'HH_WINTYPE', 'NMHDR', 'HHN_NOTIFY', 'HHNTRACK', 'HtmlHelp', 'debug', 'HH_ALINK_LOOKUP', 'HH_CLOSE_ALL', 'HH_DISPLAY_INDEX', 'HH_DISPLAY_SEARCH', 'HH_DISPLAY_TEXT_POPUP', 'HH_DISPLAY_TOC', 'HH_DISPLAY_TOPIC', 'HH_ENUM_CATEGORY', 'HH_ENUM_CATEGORY_IT', 'HH_ENUM_INFO_TYPE', 'HH_FTS_DEFAULT_PROXIMITY', 'HH_GET_LAST_ERROR', 'HH_GET_WIN_HANDLE', 'HH_GET_WIN_TYPE', 'HH_GPROPID_CONTENT_LANGUAGE', 'HH_GPROPID_CURRENT_SUBSET', 'HH_GPROPID_SINGLETHREAD', 'HH_GPROPID_TOOLBAR_MARGIN', 'HH_GPROPID_UI_LANGUAGE', 'HH_HELP_CONTEXT', 'HH_HELP_FINDER', 'HH_INITIALIZE', 'HH_KEYWORD_LOOKUP', 'HH_MAX_TABS_CUSTOM', 'HH_PRETRANSLATEMESSAGE', 'HH_RESERVED1', 'HH_RESERVED2', 'HH_RESERVED3', 'HH_RESET_IT_FILTER', 'HH_SET_EXCLUSIVE_FILTER', 'HH_SET_GLOBAL_PROPERTY', 'HH_SET_INCLUSIVE_FILTER', 'HH_SET_INFO_TYPE', 'HH_SET_WIN_TYPE', 'HH_SYNC', 'HH_TAB_AUTHOR', 'HH_TAB_CONTENTS', 'HH_TAB_CUSTOM_FIRST', 'HH_TAB_CUSTOM_LAST', 'HH_TAB_FAVORITES', 'HH_TAB_HISTORY', 'HH_TAB_INDEX', 'HH_TAB_SEARCH', 'HH_TP_HELP_CONTEXTMENU', 'HH_TP_HELP_WM_HELP', 'HH_UNINITIALIZE', 'HHACT_BACK', 'HHACT_CONTRACT', 'HHACT_CUSTOMIZE', 'HHACT_EXPAND', 'HHACT_FORWARD', 'HHACT_HIGHLIGHT', 'HHACT_HOME', 'HHACT_JUMP1', 'HHACT_JUMP2', 'HHACT_LAST_ENUM', 'HHACT_NOTES', 'HHACT_OPTIONS', 'HHACT_PRINT', 'HHACT_REFRESH', 'HHACT_STOP', 'HHACT_SYNC', 'HHACT_TAB_CONTENTS', 'HHACT_TAB_FAVORITES', 'HHACT_TAB_HISTORY', 'HHACT_TAB_INDEX', 'HHACT_TAB_SEARCH', 'HHACT_TOC_NEXT', 'HHACT_TOC_PREV', 'HHACT_ZOOM', 'HHN_FIRST', 'HHN_LAST', 'HHN_NAVCOMPLETE', 'HHN_TRACK', 'HHN_WINDOW_CREATE', 'HHWIN_BUTTON_BACK', 'HHWIN_BUTTON_BROWSE_BCK', 'HHWIN_BUTTON_BROWSE_FWD', 'HHWIN_BUTTON_CONTENTS', 'HHWIN_BUTTON_EXPAND', 'HHWIN_BUTTON_FAVORITES', 'HHWIN_BUTTON_FORWARD', 'HHWIN_BUTTON_HISTORY', 'HHWIN_BUTTON_HOME', 'HHWIN_BUTTON_INDEX', 'HHWIN_BUTTON_JUMP1', 'HHWIN_BUTTON_JUMP2', 'HHWIN_BUTTON_NOTES', 'HHWIN_BUTTON_OPTIONS', 'HHWIN_BUTTON_PRINT', 'HHWIN_BUTTON_REFRESH', 'HHWIN_BUTTON_SEARCH', 'HHWIN_BUTTON_STOP', 'HHWIN_BUTTON_SYNC', 'HHWIN_BUTTON_TOC_NEXT', 'HHWIN_BUTTON_TOC_PREV', 'HHWIN_BUTTON_ZOOM', 'HHWIN_DEF_BUTTONS', 'HHWIN_NAVTAB_BOTTOM', 'HHWIN_NAVTAB_LEFT', 'HHWIN_NAVTAB_TOP', 'HHWIN_PARAM_CUR_TAB', 'HHWIN_PARAM_EXPANSION', 'HHWIN_PARAM_EXSTYLES', 'HHWIN_PARAM_HISTORY_COUNT', 'HHWIN_PARAM_INFOTYPES', 'HHWIN_PARAM_NAV_WIDTH', 'HHWIN_PARAM_PROPERTIES', 'HHWIN_PARAM_RECT', 'HHWIN_PARAM_SHOWSTATE', 'HHWIN_PARAM_STYLES', 'HHWIN_PARAM_TABORDER', 'HHWIN_PARAM_TABPOS', 'HHWIN_PARAM_TB_FLAGS', 'HHWIN_PROP_AUTO_SYNC', 'HHWIN_PROP_CHANGE_TITLE', 'HHWIN_PROP_MENU', 'HHWIN_PROP_NAV_ONLY_WIN', 'HHWIN_PROP_NO_TOOLBAR', 'HHWIN_PROP_NODEF_EXSTYLES', 'HHWIN_PROP_NODEF_STYLES', 'HHWIN_PROP_NOTB_TEXT', 'HHWIN_PROP_NOTITLEBAR', 'HHWIN_PROP_ONTOP', 'HHWIN_PROP_POST_QUIT', 'HHWIN_PROP_TAB_ADVSEARCH', 'HHWIN_PROP_TAB_AUTOHIDESHOW', 'HHWIN_PROP_TAB_CUSTOM1', 'HHWIN_PROP_TAB_CUSTOM2', 'HHWIN_PROP_TAB_CUSTOM3', 'HHWIN_PROP_TAB_CUSTOM4', 'HHWIN_PROP_TAB_CUSTOM5', 'HHWIN_PROP_TAB_CUSTOM6', 'HHWIN_PROP_TAB_CUSTOM7', 'HHWIN_PROP_TAB_CUSTOM8', 'HHWIN_PROP_TAB_CUSTOM9', 'HHWIN_PROP_TAB_FAVORITES', 'HHWIN_PROP_TAB_HISTORY', 'HHWIN_PROP_TAB_SEARCH', 'HHWIN_PROP_TRACKING', 'HHWIN_PROP_TRI_PANE', 'HHWIN_PROP_USER_POS', 'HHWIN_TB_MARGIN', 'IDTB_BACK', 'IDTB_BROWSE_BACK', 'IDTB_BROWSE_FWD', 'IDTB_CONTENTS', 'IDTB_CONTRACT', 'IDTB_CUSTOMIZE', 'IDTB_EXPAND', 'IDTB_FAVORITES', 'IDTB_FORWARD', 'IDTB_HISTORY', 'IDTB_HOME', 'IDTB_INDEX', 'IDTB_JUMP1', 'IDTB_JUMP2', 'IDTB_NOTES', 'IDTB_OPTIONS', 'IDTB_PRINT', 'IDTB_REFRESH', 'IDTB_SEARCH', 'IDTB_STOP', 'IDTB_SYNC', 'IDTB_TOC_NEXT', 'IDTB_TOC_PREV', 'IDTB_ZOOM']
import typing
import win32typing
"""A module, encapsulating the Win32 help API's."""


def WinHelp(hwnd:'int',hlpFile:'str',cmd:'typing.Any',data:'typing.Union[str, typing.Any]'=None) -> 'None':
    """
    Invokes the Windows Help system.

Args:

      hwnd(typing.Any):The handle of the window requesting help.
      hlpFile(str):The name of the help file.
      cmd(typing.Any):The type of help.  See the api for full details.
      data(typing.Union[str, typing.Any]):Additional data specific to the help call. Can be a buffer or pointer-sized int.Win32 API References

Returns:

      None:Search for WinHelp at msdn, google or google groups.
Return ValueThe method raises an exception if an error occurs.

        
    """
    pass
        

def HH_AKLINK() -> 'win32typing.PyHH_AKLINK':
    """
    Creates a new HH_AKLINK object.

Args:



Returns:

      win32typing.PyHH_AKLINK
        
    """
    pass
        

def HH_FTS_QUERY() -> 'win32typing.PyHH_FTS_QUERY':
    """
    Creates a new HH_FTS_QUERY object.

Args:



Returns:

      win32typing.PyHH_FTS_QUERY
        
    """
    pass
        

def HH_POPUP() -> 'win32typing.PyHH_POPUP':
    """
    Creates a new HH_POPUP object.

Args:



Returns:

      win32typing.PyHH_POPUP
        
    """
    pass
        

def HH_WINTYPE() -> 'win32typing.PyHH_WINTYPE':
    """
    Creates a new HH_WINTYPE object.

Args:



Returns:

      win32typing.PyHH_WINTYPE
        
    """
    pass
        

def NMHDR() -> 'win32typing.PyNMHDR':
    """
    Creates a new NMHDR object.

Args:



Returns:

      win32typing.PyNMHDR
        
    """
    pass
        

def HHN_NOTIFY() -> 'win32typing.PyHHN_NOTIFY':
    """
    Creates a new HHN_NOTIFY object.

Args:



Returns:

      win32typing.PyHHN_NOTIFY
        
    """
    pass
        

def HHNTRACK() -> 'win32typing.PyHHNTRACK':
    """
    Creates a new HHNTRACK object.

Args:



Returns:

      win32typing.PyHHNTRACK
        
    """
    pass
        

def HtmlHelp(hwnd:'int',file:'typing.Union[str, typing.Any]',cmd:'typing.Any',data:'typing.Union[str, typing.Tuple[int], typing.Any]'=0) -> 'typing.Any':
    """
    Invokes the Windows Html Help system.

Args:

      hwnd(typing.Any):The handle of the window requesting help.
      file(typing.Union[str, typing.Any]):The name of the help file, or None.
      cmd(typing.Any):The type of help.  Valid values are:HH_ALINK_LOOKUP: Looks up one or more Associative link (ALink) names in a compiled help (.chm) file. The ALink names to search for, and the action to be taken if no matches are found, are specified in the win32help::HH_AKLINK structure.file: Specifies a compiled help (.chm) file, or a specific topic within a compiled help file.data: Specifies NULL or a pointer to a topic within a compiled help file.HH_CLOSE_ALL: Closes all windows opened directly or indirectly by the calling program.  The args are not checked for type, values are set as they "Must" be.hwnd: Must be None.file: Must be None.data: Must be zero.HH_DISPLAY_INDEX: Selects the Index tab in the Navigation pane of the HTML Help Viewer and searches for the keyword specified in the data parameter.file: Specifies a compiled help (.chm) file, or a specific topic within a compiled help file.data: Specifies the keyword to select in the index (.hhk) file.HH_DISPLAY_SEARCH: Selects the Search tab in the Navigation pane of the HTML Help Viewer and performs a search for the term specified in the searchQuery parameter of the win32help::HH_FTS_QUERY structure.file: Specifies a compiled help (.chm) file, or a specific topic within a compiled help file.data: Specifies a pointer to an win32help::HH_FTS_QUERY structure.HH_DISPLAY_TEXT_POPUP: Opens a pop-up window that displays the contents of one of the following: An explicit text string. A text string based on a resource ID. A text string ID based on a text file contained in a compiled help (.chm) file.file: To use an explicit text string, use None.  To use a text string from a resource, use None. To use text string from a text file contained in a compiled help file, specify the .chm file and the text file within the .chm file.data: Specifies a pointer to an win32help::HH_POPUP structure. HH_DISPLAY_TOC: Selects the Contents tab in the Navigation pane of the HTML Help Viewer.file: Specifies a compiled help (.chm) file, or a specific topic within a compiled help file.data: Specifies None or a pointer to a topic within a compiled help file.HH_DISPLAY_TOPIC: Opens a help topic in a specified help window. If a window type is not specified, a default window type is used. If the window type or default window type is open, the help topic replaces the current topic in the window.file: Specifies a compiled help (.chm) file, or a specific topic within a compiled help file. To specify a defined window type, insert a greater-than (&gt) character followed by the name of the window type.data: Specifies None or a pointer to a topic within a compiled help file.HH_GET_LAST_ERROR: Returns information about the last error that occurred in the HTML Help ActiveX control (Hhctrl.ocx).file: Must be Nonedata: A pointer to a HH_LAST_ERROR structure.Has not been implemented by Microsoft yetHH_GET_WIN_HANDLE: Returns the handle (hwnd) of a specified window type.file: Specifies the name of the compiled help (.chm) file in which the window type is defined.data: Specifies the name of the window type whose handle you want to return.HH_GET_WIN_TYPE: Retrieves a pointer to the win32help::HH_WINTYPE structure associated with a specified window type.file: Specifies the name of the window type whose information you want to get and the name of the compiled help (.chm) file in which the window type is defined. The window name must begin with a greater-than (&gt) character and must be preceded by the name of the compiled help file it is defined in.data: Ignored.HH_HELP_CONTEXT: Displays a help topic based on a mapped topic ID. If a window type is not specified, a default window type is used. If the window type or default window type is open, the help topic replaces the current topic in the window.file: Specifies the compiled help (.chm) file that contains the mapping information. To specify a defined window type, insert a greater-than (&gt) character followed by the name of the window type.data: Specifies the numeric ID of the topic to display. You must map symbolic IDs of dialog boxes to numeric IDs in the [MAP] section of your project (.hhp) file.HH_INITIALIZE: This command initializes the help system for use and must be the first HTML Help command called. It returns a cookie which must be used in the HH_UNINITIALIZE call. HH_INITIALIZE configures HTML Help to run on the same thread as the calling application instead of a secondary thread by setting the global property HH_GPROPID_SINGLETHREAD to VARIANT_TRUE. Running HTML Help on the same thread as the calling application requires the calling application to send messages to HTML Help by calling the HH_PRETRANSLATEMESSAGE command.file: Must be None.data: Ignored.HH_KEYWORD_LOOKUP: Looks up one or more keywords in a compiled help (.chm) file. The keywords to search for and the action to be taken if no matches are found are specified in the win32help::HH_AKLINK structure.file: Specifies the compiled help (.chm) file that contains keywords.data: Points to an win32help::HH_AKLINK structure.HH_PRETRANSLATEMESSAGE: This command is called in the message loop of your Windows application to ensure proper handling of Windows messages, especially keyboard messages when running HTML Help single thread. The HTML Help API is not thread safe and must be called from one and only one thread in a process.filedata: Points to a Win32 MSG structure.Has not been implemented yetHH_SET_WIN_TYPE: Creates a new help window or modifies an existing help window at run time.file: Specifies the name of the window type that you want to create or modify and the name of the compiled help (.chm) file in which the window type is defined. The window type name must begin with a greater-than (&gt) character and must be preceded by the name of the compiled help file in which it is defined.data: Points to an win32help::HH_WINTYPE structure.HH_SYNC: Locates and selects the contents entry for the help topic that is open in the Topic pane of the HTML Help Viewer.file: Specifies the name of the window type that you want to sync and the name of the compiled help (.chm) file in which the window type is defined. The window type name must begin with a greater-than (&gt) character and must be preceded by the name of the compiled help file in which it is defined.data: Specifies a pointer to a topic within a compiled help file. This value is the topic file to which the contents will synchronize.HH_TP_HELP_CONTEXTMENU: Opens a pop-up context menu. Generally used in response to the Windows WM_CONTEXTMENU message. For example, this message is sent when a user right-clicks a dialog box control.hwnd: Specifies the window handle of the dialog box control for which you want pop-up help to appear. This is typically the control that has focus. file: Specifies the compiled help (.chm) file, and the text file that contains the pop-up help topics. By default, the text file is named Cshelp.txt. If Cshelp.txt is located in the root of the compiled help file, then you only need to specify the help file name. If not, you must also specify the relative path.data: Specifies an array of DWORDs containing pairs of dialog box control IDs and help topic IDs. The array must be terminated by zero, as in the following example: DWORD ids[3]; ids[0] = ControlId; ids[1] = HelpId; ids[2] = 0;HH_TP_HELP_WM_HELP: Opens a pop-up help topic. Generally used in response to the Windows WM_HELP message. For example, this message is sent when a user presses F1.hwnd: Specifies the window handle of the dialog box control for which you want pop-up help to appear. This is typically the control that has focus. file: Specifies the compiled help (.chm) file, and the text file that contains the pop-up help topics. By default, the text file is named Cshelp.txt. If Cshelp.txt is located in the root of the compiled help file, then you only need to specify the help file name. If not, you must also specify the relative path.data: Specifies an array of DWORDs containing pairs of dialog box control IDs and help topic IDs. The array must be terminated by 0, as in the following example: DWORD ids[3]; ids[0] = ControlId; ids[1] = HelpId; ids[2] = 0;HH_UNINITIALIZE: This command is called to properly shut down HTML Help. This function should be the last help command the application calls. HH_UNINITIALIZE should not be called during DLL process detach, but during the normal application shutdown process.  The type of the file arg is not checked, just set to the value it "Must" be.file: Must be None.data: Specifies a cookie. This is the cookie returned by HH_INITIALIZE. 
      data(typing.Union[str, typing.Tuple[int], typing.Any]):Additional data specific to the help call.Win32 API References

Returns:

      typing.Any:Search for HtmlHelp at msdn, google or google groups.
Return ValueDepending on the specified cmd and the result:

HH_GET_WIN_TYPE



: 

tuple: (hwnd as below, and the win32help::HH_WINTYPE object). 

Deep copy the structure to which dwData points before modifying the 

structure.

HH_INITIALIZE



: 

tuple: (hwnd as below, and the cookie). 

This call returns a cookie that you must pass as the value of 

data when you call HH_UNINITIALIZE



.


All other commands



:
 

HtmlHelp() returns one or both of the following: 

The handle (hwnd) of the help window. 

NULL. In some cases, NULL indicates failure; in other cases, NULL 

indicates that the help window has not yet been created.

        
    """
    pass
        
debug = ...
HH_ALINK_LOOKUP = ...
HH_CLOSE_ALL = ...
HH_DISPLAY_INDEX = ...
HH_DISPLAY_SEARCH = ...
HH_DISPLAY_TEXT_POPUP = ...
HH_DISPLAY_TOC = ...
HH_DISPLAY_TOPIC = ...
HH_ENUM_CATEGORY = ...
HH_ENUM_CATEGORY_IT = ...
HH_ENUM_INFO_TYPE = ...
HH_FTS_DEFAULT_PROXIMITY = ...
HH_GET_LAST_ERROR = ...
HH_GET_WIN_HANDLE = ...
HH_GET_WIN_TYPE = ...
HH_GPROPID_CONTENT_LANGUAGE = ...
HH_GPROPID_CURRENT_SUBSET = ...
HH_GPROPID_SINGLETHREAD = ...
HH_GPROPID_TOOLBAR_MARGIN = ...
HH_GPROPID_UI_LANGUAGE = ...
HH_HELP_CONTEXT = ...
HH_HELP_FINDER = ...
HH_INITIALIZE = ...
HH_KEYWORD_LOOKUP = ...
HH_MAX_TABS_CUSTOM = ...
HH_PRETRANSLATEMESSAGE = ...
HH_RESERVED1 = ...
HH_RESERVED2 = ...
HH_RESERVED3 = ...
HH_RESET_IT_FILTER = ...
HH_SET_EXCLUSIVE_FILTER = ...
HH_SET_GLOBAL_PROPERTY = ...
HH_SET_INCLUSIVE_FILTER = ...
HH_SET_INFO_TYPE = ...
HH_SET_WIN_TYPE = ...
HH_SYNC = ...
HH_TAB_AUTHOR = ...
HH_TAB_CONTENTS = ...
HH_TAB_CUSTOM_FIRST = ...
HH_TAB_CUSTOM_LAST = ...
HH_TAB_FAVORITES = ...
HH_TAB_HISTORY = ...
HH_TAB_INDEX = ...
HH_TAB_SEARCH = ...
HH_TP_HELP_CONTEXTMENU = ...
HH_TP_HELP_WM_HELP = ...
HH_UNINITIALIZE = ...
HHACT_BACK = ...
HHACT_CONTRACT = ...
HHACT_CUSTOMIZE = ...
HHACT_EXPAND = ...
HHACT_FORWARD = ...
HHACT_HIGHLIGHT = ...
HHACT_HOME = ...
HHACT_JUMP1 = ...
HHACT_JUMP2 = ...
HHACT_LAST_ENUM = ...
HHACT_NOTES = ...
HHACT_OPTIONS = ...
HHACT_PRINT = ...
HHACT_REFRESH = ...
HHACT_STOP = ...
HHACT_SYNC = ...
HHACT_TAB_CONTENTS = ...
HHACT_TAB_FAVORITES = ...
HHACT_TAB_HISTORY = ...
HHACT_TAB_INDEX = ...
HHACT_TAB_SEARCH = ...
HHACT_TOC_NEXT = ...
HHACT_TOC_PREV = ...
HHACT_ZOOM = ...
HHN_FIRST = ...
HHN_LAST = ...
HHN_NAVCOMPLETE = ...
HHN_TRACK = ...
HHN_WINDOW_CREATE = ...
HHWIN_BUTTON_BACK = ...
HHWIN_BUTTON_BROWSE_BCK = ...
HHWIN_BUTTON_BROWSE_FWD = ...
HHWIN_BUTTON_CONTENTS = ...
HHWIN_BUTTON_EXPAND = ...
HHWIN_BUTTON_FAVORITES = ...
HHWIN_BUTTON_FORWARD = ...
HHWIN_BUTTON_HISTORY = ...
HHWIN_BUTTON_HOME = ...
HHWIN_BUTTON_INDEX = ...
HHWIN_BUTTON_JUMP1 = ...
HHWIN_BUTTON_JUMP2 = ...
HHWIN_BUTTON_NOTES = ...
HHWIN_BUTTON_OPTIONS = ...
HHWIN_BUTTON_PRINT = ...
HHWIN_BUTTON_REFRESH = ...
HHWIN_BUTTON_SEARCH = ...
HHWIN_BUTTON_STOP = ...
HHWIN_BUTTON_SYNC = ...
HHWIN_BUTTON_TOC_NEXT = ...
HHWIN_BUTTON_TOC_PREV = ...
HHWIN_BUTTON_ZOOM = ...
HHWIN_DEF_BUTTONS = ...
HHWIN_NAVTAB_BOTTOM = ...
HHWIN_NAVTAB_LEFT = ...
HHWIN_NAVTAB_TOP = ...
HHWIN_PARAM_CUR_TAB = ...
HHWIN_PARAM_EXPANSION = ...
HHWIN_PARAM_EXSTYLES = ...
HHWIN_PARAM_HISTORY_COUNT = ...
HHWIN_PARAM_INFOTYPES = ...
HHWIN_PARAM_NAV_WIDTH = ...
HHWIN_PARAM_PROPERTIES = ...
HHWIN_PARAM_RECT = ...
HHWIN_PARAM_SHOWSTATE = ...
HHWIN_PARAM_STYLES = ...
HHWIN_PARAM_TABORDER = ...
HHWIN_PARAM_TABPOS = ...
HHWIN_PARAM_TB_FLAGS = ...
HHWIN_PROP_AUTO_SYNC = ...
HHWIN_PROP_CHANGE_TITLE = ...
HHWIN_PROP_MENU = ...
HHWIN_PROP_NAV_ONLY_WIN = ...
HHWIN_PROP_NO_TOOLBAR = ...
HHWIN_PROP_NODEF_EXSTYLES = ...
HHWIN_PROP_NODEF_STYLES = ...
HHWIN_PROP_NOTB_TEXT = ...
HHWIN_PROP_NOTITLEBAR = ...
HHWIN_PROP_ONTOP = ...
HHWIN_PROP_POST_QUIT = ...
HHWIN_PROP_TAB_ADVSEARCH = ...
HHWIN_PROP_TAB_AUTOHIDESHOW = ...
HHWIN_PROP_TAB_CUSTOM1 = ...
HHWIN_PROP_TAB_CUSTOM2 = ...
HHWIN_PROP_TAB_CUSTOM3 = ...
HHWIN_PROP_TAB_CUSTOM4 = ...
HHWIN_PROP_TAB_CUSTOM5 = ...
HHWIN_PROP_TAB_CUSTOM6 = ...
HHWIN_PROP_TAB_CUSTOM7 = ...
HHWIN_PROP_TAB_CUSTOM8 = ...
HHWIN_PROP_TAB_CUSTOM9 = ...
HHWIN_PROP_TAB_FAVORITES = ...
HHWIN_PROP_TAB_HISTORY = ...
HHWIN_PROP_TAB_SEARCH = ...
HHWIN_PROP_TRACKING = ...
HHWIN_PROP_TRI_PANE = ...
HHWIN_PROP_USER_POS = ...
HHWIN_TB_MARGIN = ...
IDTB_BACK = ...
IDTB_BROWSE_BACK = ...
IDTB_BROWSE_FWD = ...
IDTB_CONTENTS = ...
IDTB_CONTRACT = ...
IDTB_CUSTOMIZE = ...
IDTB_EXPAND = ...
IDTB_FAVORITES = ...
IDTB_FORWARD = ...
IDTB_HISTORY = ...
IDTB_HOME = ...
IDTB_INDEX = ...
IDTB_JUMP1 = ...
IDTB_JUMP2 = ...
IDTB_NOTES = ...
IDTB_OPTIONS = ...
IDTB_PRINT = ...
IDTB_REFRESH = ...
IDTB_SEARCH = ...
IDTB_STOP = ...
IDTB_SYNC = ...
IDTB_TOC_NEXT = ...
IDTB_TOC_PREV = ...
IDTB_ZOOM = ...



__all__=['', 'ReadEventLog', 'ClearEventLog', 'BackupEventLog', 'CloseEventLog', 'DeregisterEventSource', 'NotifyChangeEventLog', 'GetNumberOfEventLogRecords', 'GetOldestEventLogRecord', 'OpenEventLog', 'RegisterEventSource', 'OpenBackupEventLog', 'ReportEvent', 'EvtOpenChannelEnum', 'EvtNextChannelPath', 'EvtOpenLog', 'EvtClearLog', 'EvtExportLog', 'EvtArchiveExportedLog', 'EvtGetExtendedStatus', 'EvtQuery', 'EvtNext', 'EvtSeek', 'EvtRender', 'EvtSubscribe', 'EvtCreateBookmark', 'EvtUpdateBookmark', 'EvtGetChannelConfigProperty', 'EvtOpenChannelConfig', 'EvtOpenSession', 'EvtOpenPublisherEnum', 'EvtNextPublisherId', 'EvtOpenPublisherMetadata', 'EvtGetPublisherMetadataProperty', 'EvtOpenEventMetadataEnum', 'EvtNextEventMetadata', 'EvtGetEventMetadataProperty', 'EvtGetLogInfo', 'EvtGetEventInfo', 'EvtGetObjectArraySize', 'EvtGetObjectArrayProperty', 'EVENTLOG_AUDIT_FAILURE', 'EVENTLOG_AUDIT_SUCCESS', 'EVENTLOG_BACKWARDS_READ', 'EVENTLOG_END_ALL_PAIRED_EVENTS', 'EVENTLOG_END_PAIRED_EVENT', 'EVENTLOG_ERROR_TYPE', 'EVENTLOG_FORWARDS_READ', 'EVENTLOG_INFORMATION_TYPE', 'EVENTLOG_PAIRED_EVENT_ACTIVE', 'EVENTLOG_PAIRED_EVENT_INACTIVE', 'EVENTLOG_SEEK_READ', 'EVENTLOG_SEQUENTIAL_READ', 'EVENTLOG_START_PAIRED_EVENT', 'EVENTLOG_SUCCESS', 'EVENTLOG_WARNING_TYPE', 'EventMetadataEventChannel', 'EventMetadataEventID', 'EventMetadataEventKeyword', 'EventMetadataEventLevel', 'EventMetadataEventMessageID', 'EventMetadataEventOpcode', 'EventMetadataEventTask', 'EventMetadataEventTemplate', 'EventMetadataEventVersion', 'EvtChannelConfigAccess', 'EvtChannelConfigClassicEventlog', 'EvtChannelConfigEnabled', 'EvtChannelConfigIsolation', 'EvtChannelConfigOwningPublisher', 'EvtChannelConfigPropertyIdEND', 'EvtChannelConfigType', 'EvtChannelLoggingConfigAutoBackup', 'EvtChannelLoggingConfigLogFilePath', 'EvtChannelLoggingConfigMaxSize', 'EvtChannelLoggingConfigRetention', 'EvtChannelPublisherList', 'EvtChannelPublishingConfigBufferSize', 'EvtChannelPublishingConfigClockType', 'EvtChannelPublishingConfigControlGuid', 'EvtChannelPublishingConfigFileMax', 'EvtChannelPublishingConfigKeywords', 'EvtChannelPublishingConfigLatency', 'EvtChannelPublishingConfigLevel', 'EvtChannelPublishingConfigMaxBuffers', 'EvtChannelPublishingConfigMinBuffers', 'EvtChannelPublishingConfigSidType', 'EvtEventMetadataPropertyIdEND', 'EvtEventPath', 'EvtEventPropertyIdEND', 'EvtEventQueryIDs', 'EvtExportLogChannelPath', 'EvtExportLogFilePath', 'EvtExportLogTolerateQueryErrors', 'EvtLogAttributes', 'EvtLogCreationTime', 'EvtLogFileSize', 'EvtLogFull', 'EvtLogLastAccessTime', 'EvtLogLastWriteTime', 'EvtLogNumberOfLogRecords', 'EvtLogOldestRecordNumber', 'EvtOpenChannelPath', 'EvtOpenFilePath', 'EvtPublisherMetadataChannelReferenceFlags', 'EvtPublisherMetadataChannelReferenceID', 'EvtPublisherMetadataChannelReferenceIndex', 'EvtPublisherMetadataChannelReferenceMessageID', 'EvtPublisherMetadataChannelReferencePath', 'EvtPublisherMetadataChannelReferences', 'EvtPublisherMetadataHelpLink', 'EvtPublisherMetadataKeywordMessageID', 'EvtPublisherMetadataKeywordName', 'EvtPublisherMetadataKeywords', 'EvtPublisherMetadataKeywordValue', 'EvtPublisherMetadataLevelMessageID', 'EvtPublisherMetadataLevelName', 'EvtPublisherMetadataLevels', 'EvtPublisherMetadataLevelValue', 'EvtPublisherMetadataMessageFilePath', 'EvtPublisherMetadataOpcodeMessageID', 'EvtPublisherMetadataOpcodeName', 'EvtPublisherMetadataOpcodes', 'EvtPublisherMetadataOpcodeValue', 'EvtPublisherMetadataParameterFilePath', 'EvtPublisherMetadataPropertyIdEND', 'EvtPublisherMetadataPublisherGuid', 'EvtPublisherMetadataPublisherMessageID', 'EvtPublisherMetadataResourceFilePath', 'EvtPublisherMetadataTaskEventGuid', 'EvtPublisherMetadataTaskMessageID', 'EvtPublisherMetadataTaskName', 'EvtPublisherMetadataTasks', 'EvtPublisherMetadataTaskValue', 'EvtQueryChannelPath', 'EvtQueryFilePath', 'EvtQueryForwardDirection', 'EvtQueryReverseDirection', 'EvtQueryTolerateQueryErrors', 'EvtRenderBookmark', 'EvtRenderEventValues', 'EvtRenderEventXml', 'EvtRpcLogin', 'EvtRpcLoginAuthDefault', 'EvtRpcLoginAuthKerberos', 'EvtRpcLoginAuthNegotiate', 'EvtRpcLoginAuthNTLM', 'EvtSeekOriginMask', 'EvtSeekRelativeToBookmark', 'EvtSeekRelativeToCurrent', 'EvtSeekRelativeToFirst', 'EvtSeekRelativeToLast', 'EvtSeekStrict', 'EvtSubscribeActionDeliver', 'EvtSubscribeActionError', 'EvtSubscribeOriginMask', 'EvtSubscribeStartAfterBookmark', 'EvtSubscribeStartAtOldestRecord', 'EvtSubscribeStrict', 'EvtSubscribeToFutureEvents', 'EvtSubscribeTolerateQueryErrors', 'EvtVarTypeAnsiString', 'EvtVarTypeBinary', 'EvtVarTypeBoolean', 'EvtVarTypeByte', 'EvtVarTypeDouble', 'EvtVarTypeEvtHandle', 'EvtVarTypeEvtXml', 'EvtVarTypeFileTime', 'EvtVarTypeGuid', 'EvtVarTypeHexInt32', 'EvtVarTypeHexInt64', 'EvtVarTypeInt16', 'EvtVarTypeInt32', 'EvtVarTypeInt64', 'EvtVarTypeNull', 'EvtVarTypeSByte', 'EvtVarTypeSid', 'EvtVarTypeSingle', 'EvtVarTypeSizeT', 'EvtVarTypeString', 'EvtVarTypeSysTime', 'EvtVarTypeUInt16', 'EvtVarTypeUInt32', 'EvtVarTypeUInt64']
import typing
import win32typing
""""""


def ReadEventLog(Handle:'typing.Any',Flags:'typing.Any',Offset:'typing.Any',Size:'typing.Any'=4096) -> 'typing.List[typing.Any]':
    """
    Reads some event log records.

Args:

      Handle(typing.Any):Handle to a an opened event log (see win32evtlog::OpenEventLog)
      Flags(typing.Any):Reading flags
      Offset(typing.Any):Record offset to read (in SEEK mode).
      Size(typing.Any):Output buffer size.Return ValueIf there are no event log records available, then an empty list is returned.

Returns:

      typing.List[typing.Any]:Output buffer size.
Return ValueIf there are no event log records available, then an empty list is returned.

        
    """
    pass
        

def ClearEventLog(handle:'typing.Any',eventLogName:'str') -> 'None':
    """
    Clears the event log

Args:

      handle(typing.Any):Handle to the event log to clear.
      eventLogName(str):The name of the event log to save to, or None

Returns:

      None
        
    """
    pass
        

def BackupEventLog(handle:'typing.Any',eventLogName:'str') -> 'None':
    """
    Backs up the event log

Args:

      handle(typing.Any):Handle to the event log to backup.
      eventLogName(str):The name of the event log to save to

Returns:

      None
        
    """
    pass
        

def CloseEventLog(handle:'typing.Any') -> 'None':
    """
    Closes the eventlog

Args:

      handle(typing.Any):Handle to the event log to close

Returns:

      None
        
    """
    pass
        

def DeregisterEventSource(handle:'typing.Any') -> 'None':
    """
    Deregisters an Event Source

Args:

      handle(typing.Any):Identifies the event log whose handle was returned by win32evtlog::RegisterEventSource

Returns:

      None
        
    """
    pass
        

def NotifyChangeEventLog(handle:'typing.Any',handle1:'typing.Any') -> 'None':
    """
    Lets an application receive notification when an event is written to the event log file specified by the hEventLog parameter. When the event is written to the event log file, the function causes the event object specified by the hEvent parameter to become signaled.

Args:

      handle(typing.Any):Handle to an event log file, obtained by calling win32evtlog::OpenEventLog function. When an event is written to this log file, the event specified by hEvent becomes signaled.
      handle1(typing.Any):A handle to a Win32 event. This is the event that becomes signaled when an event is written to the event log file specified by the hEventLog parameter.

Returns:

      None
        
    """
    pass
        

def GetNumberOfEventLogRecords(handle:'typing.Any') -> 'typing.Any':
    """
    Returns the number of event log records.

Args:

      handle(typing.Any):Handle to the event log to query.

Returns:

      typing.Any
        
    """
    pass
        

def GetOldestEventLogRecord() -> 'typing.Any':
    """
    Returns the number of event log records.

Args:



Returns:

      typing.Any:win32evtlog.GetOldestEventLogRecord

int = GetOldestEventLogRecord()Returns the number of event log records.
Return ValueThe result is the absolute record number of the oldest record in the given event log.

        
    """
    pass
        

def OpenEventLog(serverName:'str',sourceName:'str') -> 'win32typing.PyEVTLOG_HANDLE':
    """
    Opens an event log.

Args:

      serverName(str):The server name, or None
      sourceName(str):specifies the name of the source that the returned handle will reference. The source name must be a subkey of a logfile entry under the EventLog key in the registry.

Returns:

      win32typing.PyEVTLOG_HANDLE
        
    """
    pass
        

def RegisterEventSource(serverName:'str',sourceName:'str') -> 'typing.Any':
    """
    Registers an Event Source

Args:

      serverName(str):The server name, or None
      sourceName(str):The source name

Returns:

      typing.Any
        
    """
    pass
        

def OpenBackupEventLog(serverName:'str',fileName:'str') -> 'win32typing.PyEVTLOG_HANDLE':
    """
    Opens a previously saved event log.

Args:

      serverName(str):The server name, or None
      fileName(str):The filename to open

Returns:

      win32typing.PyEVTLOG_HANDLE
        
    """
    pass
        

def ReportEvent(EventLog:'int',Type:'typing.Any',Category:'typing.Any',EventID:'typing.Any',UserSid:'win32typing.PySID',Strings:'typing.Any',RawData:'typing.Any') -> 'None':
    """
    Reports an event

Args:

      EventLog(int):Handle to an event log
      Type(typing.Any):win32con.EVENTLOG_* value
      Category(typing.Any):Source-specific event category
      EventID(typing.Any):Source-specific event identifier
      UserSid(win32typing.PySID):Sid of current user, can be None
      Strings(typing.Any):Sequence of unicode strings to be inserted in message
      RawData(typing.Any):Binary data for event, can be None

Returns:

      None
        
    """
    pass
        

def EvtOpenChannelEnum(Session:'win32typing.PyEVT_HANDLE'=None,Flags:'typing.Any'=0) -> 'win32typing.PyEVT_HANDLE':
    """
    Begins an enumeration of event channels

Args:

      Session(win32typing.PyEVT_HANDLE):Handle to a remote session (see win32evtlog::EvtOpenSession), or None for local machine.
      Flags(typing.Any):Reserved, use only 0CommentsAccepts keyword args

Returns:

      win32typing.PyEVT_HANDLE
        
    """
    pass
        

def EvtNextChannelPath(ChannelEnum:'win32typing.PyEVT_HANDLE') -> 'typing.Any':
    """
    Retrieves a channel path from an enumeration

Args:

      ChannelEnum(win32typing.PyEVT_HANDLE):Handle to an enumeration as returned by win32evtlog::EvtOpenChannelEnumCommentsAccepts keyword argsReturn ValueReturns None at end of enumeration

Returns:

      typing.Any:Handle to an enumeration as returned by win32evtlog::EvtOpenChannelEnumComments

Accepts keyword args
Return ValueReturns None at end of enumeration

        
    """
    pass
        

def EvtOpenLog(Path:'typing.Any',Flags:'typing.Any',Session:'win32typing.PyEVT_HANDLE'=None) -> 'win32typing.PyEVT_HANDLE':
    """
    Opens an event log or exported log archive

Args:

      Path(typing.Any):Event log name or Path of an export file
      Flags(typing.Any):EvtOpenChannelPath (1) or EvtOpenFilePath (2)
      Session(win32typing.PyEVT_HANDLE):Handle to a remote session (see win32evtlog::EvtOpenSession), or None for local machine.CommentsAccepts keyword args

Returns:

      win32typing.PyEVT_HANDLE
        
    """
    pass
        

def EvtClearLog(ChannelPath:'typing.Any',TargetFilePath:'typing.Any'=None,Session:'win32typing.PyEVT_HANDLE'=None,Flags:'typing.Any'=0) -> 'None':
    """
    Clears an event log and optionally exports events to an archive

Args:

      ChannelPath(typing.Any):Name of event log to be cleared
      TargetFilePath(typing.Any):Name of file in which cleared events will be archived, or None
      Session(win32typing.PyEVT_HANDLE):Handle to a remote session (see win32evtlog::EvtOpenSession), or None for local machine.
      Flags(typing.Any):Reserved, use only 0CommentsAccepts keyword args

Returns:

      None
        
    """
    pass
        

def EvtExportLog(Path:'typing.Any',TargetFilePath:'typing.Any',Flags:'typing.Any',Query:'typing.Any'=None,Session:'win32typing.PyEVT_HANDLE'=None) -> 'None':
    """
    Exports events from a channel or log file

Args:

      Path(typing.Any):Path of a live event log channel or exported log file
      TargetFilePath(typing.Any):File to create, cannot already exist
      Flags(typing.Any):Combination of EvtExportLog* flags specifying the type of path
      Query(typing.Any):Selects specific events to export
      Session(win32typing.PyEVT_HANDLE):Handle to a remote session (see win32evtlog::EvtOpenSession), or None for local machine.CommentsAccepts keyword args

Returns:

      None
        
    """
    pass
        

def EvtArchiveExportedLog(LogFilePath:'typing.Any',Locale:'typing.Any',Session:'win32typing.PyEVT_HANDLE'=None,Flags:'typing.Any'=0) -> 'None':
    """
    Localizes an exported event log file

Args:

      LogFilePath(typing.Any):Filename of an exported log file
      Locale(typing.Any):Locale id
      Session(win32typing.PyEVT_HANDLE):Handle to a remote session (see win32evtlog::EvtOpenSession), or None for local machine.
      Flags(typing.Any):ReservedCommentsAccepts keyword args

Returns:

      None
        
    """
    pass
        

def EvtGetExtendedStatus() -> 'typing.Any':
    """
    Returns additional error info from last Evt* call

Args:



Returns:

      typing.Any
        
    """
    pass
        

def EvtQuery(Path:'typing.Any',Flags:'typing.Any',Query:'typing.Any'=None,Session:'win32typing.PyEVT_HANDLE'=None) -> 'win32typing.PyEVT_HANDLE':
    """
    Opens a query over a log channel or exported log file

Args:

      Path(typing.Any):Log channel or exported log file, depending on Flags
      Flags(typing.Any):Combination of EVT_QUERY_FLAGS (EvtQuery*)
      Query(typing.Any):Selects events to return, None or '*' for all events
      Session(win32typing.PyEVT_HANDLE):Handle to a remote session (see win32evtlog::EvtOpenSession), or None for local machine.CommentsAccepts keyword args

Returns:

      win32typing.PyEVT_HANDLE
        
    """
    pass
        

def EvtNext(ResultSet:'win32typing.PyEVT_HANDLE',Count:'typing.Any',Timeout:'typing.Any'=-1,Flags:'typing.Any'=0) -> 'typing.Tuple[win32typing.PyEVT_HANDLE, ...]':
    """
    Returns events from a query

Args:

      ResultSet(win32typing.PyEVT_HANDLE):Handle to event query or subscription
      Count(typing.Any):Number of events to return
      Timeout(typing.Any):Time to wait in milliseconds, use -1 for infinite
      Flags(typing.Any):Reserved, use only 0CommentsAccepts keyword argsReturn ValueReturns a tuple of handles to events.  If no items are available, returns an empty tuple instead of raising an exception.

Returns:

      typing.Tuple[win32typing.PyEVT_HANDLE, ...]:Reserved, use only 0
Comments

Accepts keyword args
Return ValueReturns a tuple of handles to events.  If no items are available, returns 

an empty tuple instead of raising an exception.

        
    """
    pass
        

def EvtSeek(ResultSet:'win32typing.PyEVT_HANDLE',Position:'typing.Any',Flags:'typing.Any',Bookmark:'win32typing.PyEVT_HANDLE'=None,Timeout:'typing.Any'=0) -> 'None':
    """
    Changes the current position in a result set

Args:

      ResultSet(win32typing.PyEVT_HANDLE):Handle to event query or subscription
      Position(typing.Any):Offset (base from which to seek is specified by Flags)
      Flags(typing.Any):EvtSeekRelative* flag indicating seek origin
      Bookmark(win32typing.PyEVT_HANDLE):Used as seek origin only if Flags contains EvtSeekRelativeToBookmark
      Timeout(typing.Any):Reserved, use only 0CommentsAccepts keyword args

Returns:

      None
        
    """
    pass
        

def EvtRender(Event:'win32typing.PyEVT_HANDLE',Flags:'typing.Any') -> 'typing.Any':
    """
    Formats an event into XML text

Args:

      Event(win32typing.PyEVT_HANDLE):Handle to an event or bookmark
      Flags(typing.Any):EvtRenderEventXml or EvtRenderBookmark indicating type of handleCommentsAccepts keyword argsRendering event values (Flags=EvtRenderEventValues) is not currently supported

Returns:

      typing.Any
        
    """
    pass
        

def EvtSubscribe(ChannelPath:'typing.Any',Flags:'typing.Any',SignalEvent:'typing.Any'=None,Callback:'typing.Any'=None,Context:'typing.Any'=None,Query:'typing.Any'=None,Session:'win32typing.PyEVT_HANDLE'=None,Bookmark:'win32typing.PyEVT_HANDLE'=None) -> 'win32typing.PyEVT_HANDLE':
    """
    Requests notification for events

Args:

      ChannelPath(typing.Any):Name of an event log channel
      Flags(typing.Any):Combination of EvtSubscribe* flags determining how subscription is initiated
      SignalEvent(typing.Any):An event handle to be set when events are available (see win32event::CreateEvent)
      Callback(typing.Any):Python function to be called with each event
      Context(typing.Any):Arbitrary object to be passed to the callback function
      Query(typing.Any):XML query used to select specific events, use None or '*' for all events
      Session(win32typing.PyEVT_HANDLE):Handle to a session on another machine, or None for local
      Bookmark(win32typing.PyEVT_HANDLE):If Flags contains EvtSubscribeStartAfterBookmark, used as starting pointCommentsAccepts keyword argsThe method used to receive events is determined by the parameters passed in. To create a push subscription, define a callback function that will be called with each event. The function will receive 3 args: First is an integer specifying why the function was called (EvtSubscribeActionError or EvtSubscribeActionDeliver) Second is the context object passed to EvtSubscribe. Third is the handle to an event log record (if not called due to an error) If an event handle is passed in, a pull subscription is created.  The event handle will be signalled when events are available, and the subscription handle can be passed to win32evtlog::EvtNext to obtain the events.

Returns:

      win32typing.PyEVT_HANDLE
        
    """
    pass
        

def EvtCreateBookmark(BookmarkXML:'typing.Any'=None) -> 'win32typing.PyEVT_HANDLE':
    """
    Creates a bookmark

Args:

      BookmarkXML(typing.Any):XML representation of a bookmark as returned by win32evtlog::EvtRender, or None for a new bookmarkCommentsAccepts keyword args

Returns:

      win32typing.PyEVT_HANDLE
        
    """
    pass
        

def EvtUpdateBookmark(Bookmark:'win32typing.PyEVT_HANDLE',Event:'win32typing.PyEVT_HANDLE') -> 'win32typing.PyEVT_HANDLE':
    """
    Repositions a bookmark to an event

Args:

      Bookmark(win32typing.PyEVT_HANDLE):Handle to a bookmark
      Event(win32typing.PyEVT_HANDLE):Handle to an eventCommentsAccepts keyword args

Returns:

      win32typing.PyEVT_HANDLE
        
    """
    pass
        

def EvtGetChannelConfigProperty(ChannelConfig:'win32typing.PyEVT_HANDLE',PropertyId:'typing.Any',Flags:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Retreives channel configuration information

Args:

      ChannelConfig(win32typing.PyEVT_HANDLE):Config handle as returned by win32evtlog::EvtOpenChannelConfig
      PropertyId(typing.Any):Property to retreive, one of EvtChannel* constants
      Flags(typing.Any):Reserved, use only 0CommentsAccepts keyword argsReturns the value and type of value (EvtVarType*)

Returns:

      typing.Tuple[typing.Any, typing.Any]
        
    """
    pass
        

def EvtOpenChannelConfig(ChannelPath:'typing.Any',Session:'win32typing.PyEVT_HANDLE'=None,Flags:'typing.Any'=0) -> 'win32typing.PyEVT_HANDLE':
    """
    Opens channel configuration

Args:

      ChannelPath(typing.Any):Channel to be opened
      Session(win32typing.PyEVT_HANDLE):Session handle as returned by win32evtlog::EvtOpenSession, or None for local machine
      Flags(typing.Any):Reserved, use only 0CommentsAccepts keyword args

Returns:

      win32typing.PyEVT_HANDLE
        
    """
    pass
        

def EvtOpenSession(Login:'win32typing.PyEVT_RPC_LOGIN',LoginClass:'typing.Any',Timeout:'typing.Any'=0,Flags:'typing.Any'=0) -> 'win32typing.PyEVT_HANDLE':
    """
    Creates a session used to access the Event Log on another machine

Args:

      Login(win32typing.PyEVT_RPC_LOGIN):Credentials to be used to access remote machine
      LoginClass(typing.Any):Type of login to perform, EvtRpcLogin is only defined value
      Timeout(typing.Any):Reserved, use only 0
      Flags(typing.Any):Reserved, use only 0CommentsAccepts keyword args

Returns:

      win32typing.PyEVT_HANDLE
        
    """
    pass
        

def EvtOpenPublisherEnum(Session:'win32typing.PyEVT_HANDLE'=None,Flags:'typing.Any'=0) -> 'win32typing.PyEVT_HANDLE':
    """
    Begins an enumeration of event publishers

Args:

      Session(win32typing.PyEVT_HANDLE):Handle to a remote session (see win32evtlog::EvtOpenSession), or None for local machine.
      Flags(typing.Any):Reserved, use only 0CommentsAccepts keyword args

Returns:

      win32typing.PyEVT_HANDLE
        
    """
    pass
        

def EvtNextPublisherId(PublisherEnum:'win32typing.PyEVT_HANDLE') -> 'typing.Any':
    """
    Returns the next publisher from an enumeration

Args:

      PublisherEnum(win32typing.PyEVT_HANDLE):Handle to an enumeration as returned by win32evtlog::EvtOpenPublisherEnumCommentsAccepts keyword argsReturn ValueReturns None at end of enumeration

Returns:

      typing.Any:Handle to an enumeration as returned by win32evtlog::EvtOpenPublisherEnumComments

Accepts keyword args
Return ValueReturns None at end of enumeration

        
    """
    pass
        

def EvtOpenPublisherMetadata(PublisherIdentity:'typing.Any',Session:'win32typing.PyEVT_HANDLE'=None,LogFilePath:'typing.Any'=None,Locale:'typing.Any'=0,Flags:'typing.Any'=0) -> 'win32typing.PyEVT_HANDLE':
    """
    None

Args:

      PublisherIdentity(typing.Any):Publisher id as returned by win32evtlog::EvtNextPublisherId
      Session(win32typing.PyEVT_HANDLE):Handle to remote session, or None for local machine
      LogFilePath(typing.Any):Log file from which to retrieve publisher, or None for locally registered publisher
      Locale(typing.Any):Locale to use for retrieved properties, use 0 for current locale
      Flags(typing.Any):Reserved, use only 0CommentsAccepts keyword args

Returns:

      win32typing.PyEVT_HANDLE
        
    """
    pass
        

def EvtGetPublisherMetadataProperty(PublisherMetadata:'win32typing.PyEVT_HANDLE',PropertyId:'typing.Any',Flags:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Retrieves a property from an event publisher

Args:

      PublisherMetadata(win32typing.PyEVT_HANDLE):Publisher handle as returned by win32evtlog::EvtOpenPublisherMetadata
      PropertyId(typing.Any):Property to retreive, EvtPublisherMetadata*
      Flags(typing.Any):Reserved, use only 0CommentsAccepts keyword argsReturn ValueReturns the value and type of value (EvtVarType*) Some properties return a handle (type EvtVarTypeEvtHandle) which can be iterated using win32evtlog::EvtGetObjectArraySize and win32evtlog::EvtGetObjectArrayProperty.

Returns:

      typing.Tuple[typing.Any, typing.Any]:Reserved, use only 0
Comments

Accepts keyword args
Return ValueReturns the value and type of value (EvtVarType*) 

Some properties return a handle (type EvtVarTypeEvtHandle) which can be iterated using 

win32evtlog::EvtGetObjectArraySize and win32evtlog::EvtGetObjectArrayProperty.

        
    """
    pass
        

def EvtOpenEventMetadataEnum(PublisherMetadata:'win32typing.PyEVT_HANDLE',Flags:'typing.Any'=0) -> 'win32typing.PyEVT_HANDLE':
    """
    Enumerates the events that a publisher provides

Args:

      PublisherMetadata(win32typing.PyEVT_HANDLE):Publisher handle as returned by win32evtlog::EvtOpenPublisherMetadata
      Flags(typing.Any):Reserved, use only 0CommentsAccepts keyword args

Returns:

      win32typing.PyEVT_HANDLE
        
    """
    pass
        

def EvtNextEventMetadata(EventMetadataEnum:'win32typing.PyEVT_HANDLE',Flags:'typing.Any'=0) -> 'win32typing.PyEVT_HANDLE':
    """
    Retrieves the next item from an event metadata enumeration

Args:

      EventMetadataEnum(win32typing.PyEVT_HANDLE):Enumeration handle as returned by win32evtlog::EvtOpenEventMetadataEnum
      Flags(typing.Any):Reserved, use only 0CommentsAccepts keyword args

Returns:

      win32typing.PyEVT_HANDLE
        
    """
    pass
        

def EvtGetEventMetadataProperty(EventMetadata:'win32typing.PyEVT_HANDLE',PropertyId:'typing.Any',Flags:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Retrieves a property from an event publisher

Args:

      EventMetadata(win32typing.PyEVT_HANDLE):Event metadata handle as returned by win32evtlog::EvtNextEventMetadata
      PropertyId(typing.Any):Property to retreive, EventMetadata*
      Flags(typing.Any):Reserved, use only 0CommentsAccepts keyword argsReturn ValueReturns the value and type of value (EvtVarType*).

Returns:

      typing.Tuple[typing.Any, typing.Any]:Reserved, use only 0
Comments

Accepts keyword args
Return ValueReturns the value and type of value (EvtVarType*).

        
    """
    pass
        

def EvtGetLogInfo(Log:'win32typing.PyEVT_HANDLE',PropertyId:'typing.Any') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Retrieves log file or channel information

Args:

      Log(win32typing.PyEVT_HANDLE):Event log handle as returned by win32evtlog::EvtOpenLog
      PropertyId(typing.Any):Property to retreive, EvtLog*CommentsAccepts keyword argsReturns the value and type of value (EvtVarType*)

Returns:

      typing.Tuple[typing.Any, typing.Any]
        
    """
    pass
        

def EvtGetEventInfo(Event:'win32typing.PyEVT_HANDLE',PropertyId:'typing.Any') -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Retrieves information about the source of an event

Args:

      Event(win32typing.PyEVT_HANDLE):Handle to an event
      PropertyId(typing.Any):Property to retreive, EvtEvent*CommentsAccepts keyword argsReturns the value and type of value (EvtVarType*)

Returns:

      typing.Tuple[typing.Any, typing.Any]
        
    """
    pass
        

def EvtGetObjectArraySize(ObjectArray:'win32typing.PyEVT_HANDLE') -> 'typing.Any':
    """
    Returns the size of an array of event objects

Args:

      ObjectArray(win32typing.PyEVT_HANDLE):Handle to an array of objects as returned by win32evtlog::EvtGetPublisherMetadataProperty for some ProperyId'sCommentsAccepts keyword args

Returns:

      typing.Any
        
    """
    pass
        

def EvtGetObjectArrayProperty(ObjectArray:'win32typing.PyEVT_HANDLE',PropertyId:'typing.Any',ArrayIndex:'typing.Any',Flags:'typing.Any'=0) -> 'typing.Tuple[typing.Any, typing.Any]':
    """
    Retrieves an item from an object array

Args:

      ObjectArray(win32typing.PyEVT_HANDLE):Handle to an array of objects as returned by win32evtlog::EvtGetPublisherMetadataProperty for some ProperyId's
      PropertyId(typing.Any):Type of property contained in the array
      ArrayIndex(typing.Any):Zero-based index of item to retrieve
      Flags(typing.Any):Reserved, use only 0CommentsAccepts keyword argsReturn ValueReturns the value and type of value (EvtVarType*)

Returns:

      typing.Tuple[typing.Any, typing.Any]:Reserved, use only 0
Comments

Accepts keyword args
Return ValueReturns the value and type of value (EvtVarType*)

        
    """
    pass
        
EVENTLOG_AUDIT_FAILURE = ...
EVENTLOG_AUDIT_SUCCESS = ...
EVENTLOG_BACKWARDS_READ = ...
EVENTLOG_END_ALL_PAIRED_EVENTS = ...
EVENTLOG_END_PAIRED_EVENT = ...
EVENTLOG_ERROR_TYPE = ...
EVENTLOG_FORWARDS_READ = ...
EVENTLOG_INFORMATION_TYPE = ...
EVENTLOG_PAIRED_EVENT_ACTIVE = ...
EVENTLOG_PAIRED_EVENT_INACTIVE = ...
EVENTLOG_SEEK_READ = ...
EVENTLOG_SEQUENTIAL_READ = ...
EVENTLOG_START_PAIRED_EVENT = ...
EVENTLOG_SUCCESS = ...
EVENTLOG_WARNING_TYPE = ...
EventMetadataEventChannel = ...
EventMetadataEventID = ...
EventMetadataEventKeyword = ...
EventMetadataEventLevel = ...
EventMetadataEventMessageID = ...
EventMetadataEventOpcode = ...
EventMetadataEventTask = ...
EventMetadataEventTemplate = ...
EventMetadataEventVersion = ...
EvtChannelConfigAccess = ...
EvtChannelConfigClassicEventlog = ...
EvtChannelConfigEnabled = ...
EvtChannelConfigIsolation = ...
EvtChannelConfigOwningPublisher = ...
EvtChannelConfigPropertyIdEND = ...
EvtChannelConfigType = ...
EvtChannelLoggingConfigAutoBackup = ...
EvtChannelLoggingConfigLogFilePath = ...
EvtChannelLoggingConfigMaxSize = ...
EvtChannelLoggingConfigRetention = ...
EvtChannelPublisherList = ...
EvtChannelPublishingConfigBufferSize = ...
EvtChannelPublishingConfigClockType = ...
EvtChannelPublishingConfigControlGuid = ...
EvtChannelPublishingConfigFileMax = ...
EvtChannelPublishingConfigKeywords = ...
EvtChannelPublishingConfigLatency = ...
EvtChannelPublishingConfigLevel = ...
EvtChannelPublishingConfigMaxBuffers = ...
EvtChannelPublishingConfigMinBuffers = ...
EvtChannelPublishingConfigSidType = ...
EvtEventMetadataPropertyIdEND = ...
EvtEventPath = ...
EvtEventPropertyIdEND = ...
EvtEventQueryIDs = ...
EvtExportLogChannelPath = ...
EvtExportLogFilePath = ...
EvtExportLogTolerateQueryErrors = ...
EvtLogAttributes = ...
EvtLogCreationTime = ...
EvtLogFileSize = ...
EvtLogFull = ...
EvtLogLastAccessTime = ...
EvtLogLastWriteTime = ...
EvtLogNumberOfLogRecords = ...
EvtLogOldestRecordNumber = ...
EvtOpenChannelPath = ...
EvtOpenFilePath = ...
EvtPublisherMetadataChannelReferenceFlags = ...
EvtPublisherMetadataChannelReferenceID = ...
EvtPublisherMetadataChannelReferenceIndex = ...
EvtPublisherMetadataChannelReferenceMessageID = ...
EvtPublisherMetadataChannelReferencePath = ...
EvtPublisherMetadataChannelReferences = ...
EvtPublisherMetadataHelpLink = ...
EvtPublisherMetadataKeywordMessageID = ...
EvtPublisherMetadataKeywordName = ...
EvtPublisherMetadataKeywords = ...
EvtPublisherMetadataKeywordValue = ...
EvtPublisherMetadataLevelMessageID = ...
EvtPublisherMetadataLevelName = ...
EvtPublisherMetadataLevels = ...
EvtPublisherMetadataLevelValue = ...
EvtPublisherMetadataMessageFilePath = ...
EvtPublisherMetadataOpcodeMessageID = ...
EvtPublisherMetadataOpcodeName = ...
EvtPublisherMetadataOpcodes = ...
EvtPublisherMetadataOpcodeValue = ...
EvtPublisherMetadataParameterFilePath = ...
EvtPublisherMetadataPropertyIdEND = ...
EvtPublisherMetadataPublisherGuid = ...
EvtPublisherMetadataPublisherMessageID = ...
EvtPublisherMetadataResourceFilePath = ...
EvtPublisherMetadataTaskEventGuid = ...
EvtPublisherMetadataTaskMessageID = ...
EvtPublisherMetadataTaskName = ...
EvtPublisherMetadataTasks = ...
EvtPublisherMetadataTaskValue = ...
EvtQueryChannelPath = ...
EvtQueryFilePath = ...
EvtQueryForwardDirection = ...
EvtQueryReverseDirection = ...
EvtQueryTolerateQueryErrors = ...
EvtRenderBookmark = ...
EvtRenderEventValues = ...
EvtRenderEventXml = ...
EvtRpcLogin = ...
EvtRpcLoginAuthDefault = ...
EvtRpcLoginAuthKerberos = ...
EvtRpcLoginAuthNegotiate = ...
EvtRpcLoginAuthNTLM = ...
EvtSeekOriginMask = ...
EvtSeekRelativeToBookmark = ...
EvtSeekRelativeToCurrent = ...
EvtSeekRelativeToFirst = ...
EvtSeekRelativeToLast = ...
EvtSeekStrict = ...
EvtSubscribeActionDeliver = ...
EvtSubscribeActionError = ...
EvtSubscribeOriginMask = ...
EvtSubscribeStartAfterBookmark = ...
EvtSubscribeStartAtOldestRecord = ...
EvtSubscribeStrict = ...
EvtSubscribeToFutureEvents = ...
EvtSubscribeTolerateQueryErrors = ...
EvtVarTypeAnsiString = ...
EvtVarTypeBinary = ...
EvtVarTypeBoolean = ...
EvtVarTypeByte = ...
EvtVarTypeDouble = ...
EvtVarTypeEvtHandle = ...
EvtVarTypeEvtXml = ...
EvtVarTypeFileTime = ...
EvtVarTypeGuid = ...
EvtVarTypeHexInt32 = ...
EvtVarTypeHexInt64 = ...
EvtVarTypeInt16 = ...
EvtVarTypeInt32 = ...
EvtVarTypeInt64 = ...
EvtVarTypeNull = ...
EvtVarTypeSByte = ...
EvtVarTypeSid = ...
EvtVarTypeSingle = ...
EvtVarTypeSizeT = ...
EvtVarTypeString = ...
EvtVarTypeSysTime = ...
EvtVarTypeUInt16 = ...
EvtVarTypeUInt32 = ...
EvtVarTypeUInt64 = ...
